import { getRetryErrorHandler } from '@avst-api/commons';
export class ErrorStrategyBuilder {
    constructor(options = {}) {
        this.options = options;
    }
    static create() {
        return new ErrorStrategyBuilder();
    }
    /**
     * Error handler for HTTP code 400 (Bad Request). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http400Error(handler) {
        this.options.handleHttp400Error = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for HTTP code 401 (Unauthorized). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http401Error(handler) {
        this.options.handleHttp401Error = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for HTTP code 403 (Forbidden). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http403Error(handler) {
        this.options.handleHttp403Error = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for HTTP code 404 (Not Found). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http404Error(handler) {
        this.options.handleHttp404Error = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for HTTP code 429 (Too Many Requests). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http429Error(handler) {
        this.options.handleHttp429Error = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for any HTTP code in 500 range (various server side errors). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    http5xxError(handler) {
        this.options.handleHttp5xxError = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for any invalid HTTP code (anything other than in 200 and 300 range). Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    httpAnyError(handler) {
        this.options.handleHttpAnyError = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for unexpected error, usually either network error or JSON parsing error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    unexpectedError(handler) {
        this.options.handleUnexpectedError = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Error handler for any error. Return the value you whish to continue with, or return 'retry()' for retrying the request, or return 'continuePropagation()' for allowing the error to propagate.
     */
    anyError(handler) {
        this.options.handleAnyError = handler;
        return new ErrorStrategyBuilder(this.options);
    }
    /**
     * Retry when HTTP request is being rate limited (429 response).
     * @param total How many times to re-try. Set to -1 to retry indefinitely (default).
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value (default).
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnRateLimiting(total = -1, delay = -1, delayIncrease = 1000) {
        return this.http429Error(getRetryErrorHandler(total, delay, delayIncrease));
    }
    /**
     * Retry on any HTTP error.
     * @param total How many times to re-try. Set to -1 to retry indefinitely. Default: 3.
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value. Default: 1 second.
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnHttpError(total = 3, delay = 1000, delayIncrease = 1000) {
        return this.httpAnyError(getRetryErrorHandler(total, delay, delayIncrease));
    }
    /**
     * Retry on any failure.
     * @param total How many times to re-try. Set to -1 to retry indefinitely. Default: 3.
     * @param delay How long to delay before re-trying again, in milliseconds. Set to -1 to try to follow 'Retry-After' header value. Default: 1 second.
     * @param delayIncrease Delay to increase per each unsuccessful re-try, in milliseconds. Default: 1 second.
     */
    retryOnAnyError(total = 3, delay = 1000, delayIncrease = 1000) {
        return this.anyError(getRetryErrorHandler(total, delay, delayIncrease));
    }
    build() {
        return this.options;
    }
}
