import { getFields } from '../raw-api/common';
import { RequestValidationError, looksLikeNumber } from '@avst-api/commons';
export class IssueBuilder {
    constructor(cacheManager, fieldOperations = []) {
        this.cacheManager = cacheManager;
        this.fieldOperations = fieldOperations;
    }
    clearCache() {
        this.cacheManager.clearCache();
        return this.getNewInstance();
    }
    /**
     * Sets the project.
     * @param project Project ID or key or project object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withProject(project, updateOperation) {
        this.fieldOperations.push({
            id: 'project',
            name: 'project',
            value: project,
            updateOperation,
            isErrorInProcessProjectValue: false
        });
        return this.getNewInstance();
    }
    /**
     * Sets the issue type.
     * @param issueType Issue type ID or name or issue type object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withIssueType(issueType, updateOperation) {
        this.fieldOperations.push({
            id: 'issuetype',
            name: 'issuetype',
            value: issueType,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the components.
     * @param components Array of component IDs or component object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withComponents(components, updateOperation) {
        this.fieldOperations.push({
            id: 'components',
            name: 'components',
            value: components,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the assignee.
     * @param assignee Assignee's accountId;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withAssignee(assignee, updateOperation) {
        this.fieldOperations.push({
            id: 'assignee',
            name: 'assignee',
            value: assignee,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the fix versions.
     * @param fixVersions Array of fix version IDs or version objects;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withFixVersions(fixVersions, updateOperation) {
        this.fieldOperations.push({
            id: 'fixVersions',
            name: 'fixVersions',
            value: fixVersions,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the priority.
     * @param priority Priority ID, name or priority object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withPriority(priority, updateOperation) {
        this.fieldOperations.push({
            id: 'priority',
            name: 'priority',
            value: priority,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the versions.
     * @param versions Array of version IDs or version objects;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withVersions(versions, updateOperation) {
        this.fieldOperations.push({
            id: 'versions',
            name: 'versions',
            value: versions,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the security.
     * @param security Security level id;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withSecurity(security, updateOperation) {
        this.fieldOperations.push({
            id: 'security',
            name: 'security',
            value: security,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the labels.
     * @param labels Array of labels;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withLabels(labels, updateOperation) {
        this.fieldOperations.push({
            id: 'labels',
            name: 'labels',
            value: labels,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the due date.
     * @param dueDate Due date for the issue either as a ISO 8601 string or date object;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDueDate(dueDate, updateOperation) {
        this.fieldOperations.push({
            id: 'duedate',
            name: 'dueDate',
            value: dueDate,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the description.
     * @param description Issue description as a string;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDescription(description, updateOperation) {
        this.fieldOperations.push({
            id: 'description',
            name: 'description',
            value: description,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the environment.
     * @param environment Issue environment as a string;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEnvironment(environment, updateOperation) {
        this.fieldOperations.push({
            id: 'environment',
            name: 'environment',
            value: environment,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the resolution while updating an issue.
     * @param resolution Issue resolution ID, name or resolution obejct;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withResolution(resolution, updateOperation) {
        this.fieldOperations.push({
            id: 'resolution',
            name: 'resolution',
            value: resolution,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the summary.
     * @param summary Issue summary string;
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withSummary(summary, updateOperation) {
        this.fieldOperations.push({
            id: 'summary',
            name: 'summary',
            value: summary,
            updateOperation
        });
        return this.getNewInstance();
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withTextCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    //TODO: Add support for Sprint custom field (com.pyxis.greenhopper.jira:gh-sprint)
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withReadOnlyTextCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: literal color.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withIssueColorCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: uuid.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withUUIDCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value for issues with epic issue type.
     * ghx-label-1 - brown
     * ghx-label-2 - yellow
     * ghx-label-3 - light brown
     * ghx-label-4 - dark blue
     * ghx-label-5 - light blue
     * ghx-label-6 - light green
     * ghx-label-7 - coral/orange
     * ghx-label-8 - dark purple
     * ghx-label-9 - light pink
     * ghx-label-10 - lavender
     * ghx-label-11 - light aqua
     * ghx-label-12- light gray
     * ghx-label-13 - dark green
     * ghx-label-14 - dark coral/red(ish)
     * @param customField Custom field ID or name.
     * @param value Custom field value: epic color.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicColorCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value for issues with epic issue type.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicStatusCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: epic issue key.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicLinkCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value for issues with epic issue type.
     * @param customField Custom field ID or name.
     * @param value Custom field value: name.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withEpicNameCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withNumberCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withProjectPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of option IDs.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiSelectCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either ISO 8601 string or Date object.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDatePickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field option ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withSelectCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of option IDs.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiCheckBoxesCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, ISO 8601 string.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withDateTimePickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of labels.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withLabelsCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field option ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withRadioButtonsCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either Content object or string.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiLineTextCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either string or URL object.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withURLCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: username.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withUserPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of group names.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiGroupPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value: Group's name.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withGroupPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of User's names.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiUserPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, an array of either option keys or IDs.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withMultiVersionPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    /**
     * Sets the custom field value.
     * @param customField Custom field ID or name.
     * @param value Custom field value, either option key or ID.
     * @param updateOperation You can optionally specify update operation if you wish to send the value under 'update' property, if it is not specified the value will be sent under 'fields' property.
     */
    withVersionPickerCustomField(customField, value, updateOperation) {
        return this.setCustomField(customField, value, updateOperation);
    }
    buildCreateRequest() {
        return this.build();
    }
    buildUpdateRequest() {
        return this.build();
    }
    async build() {
        const request = {};
        const promises = [];
        this.fieldOperations.forEach(fieldOperation => promises.push(this.processField(fieldOperation, request)));
        await Promise.all(promises);
        return request;
    }
    async processField(fieldOperation, request) {
        const fieldOp = await this.populateFieldId(fieldOperation);
        const fo = await this.processValues(fieldOp);
        if (!fo.updateOperation) {
            if (!request.fields) {
                request.fields = {};
            }
            request.fields[fo.id] = fo.value;
        }
        else {
            if (!request.update) {
                request.update = {};
            }
            if (!request.update[fo.id]) {
                request.update[fo.id] = [];
            }
            request.update[fo.id].push({ [fo.updateOperation]: fo.value });
        }
    }
    async populateFieldId(fieldOperation) {
        if (fieldOperation.id) {
            return fieldOperation;
        }
        else {
            const fields = await this.cacheManager.getAllFields();
            const customFields = getFields(fields, fieldOperation.name);
            if (customFields.length === 0) {
                throw new RequestValidationError([`Custom field not found: ${fieldOperation.name}`]);
            }
            else if (customFields.length === 1) {
                fieldOperation.id = customFields[0].id;
                return fieldOperation;
            }
            else {
                throw new RequestValidationError([`Found too many matching custom fields: ${fieldOperation.name}, please consider using field ID instead`]);
            }
        }
    }
    async processValues(fieldOperation) {
        switch (fieldOperation.name) {
            case 'project':
                return this.processProjectValue(fieldOperation);
            case 'issuetype':
                return this.processIssueType(fieldOperation);
            case 'components':
                return this.processMultiIDField(fieldOperation);
            case 'assignee':
                return this.processAssignee(fieldOperation);
            case 'fixVersions':
                return this.processMultiIDField(fieldOperation);
            case 'priority':
                return this.processPriority(fieldOperation);
            case 'versions':
                return this.processMultiIDField(fieldOperation);
            case 'security':
                return this.processSecurity(fieldOperation);
            case 'description':
                return this.processTextAreaField(fieldOperation);
            case 'environment':
                return this.processTextAreaField(fieldOperation);
            case 'dueDate':
                return this.processDateField(fieldOperation);
            case 'resolution':
                return this.processResolution(fieldOperation);
        }
        if (fieldOperation.id.startsWith('customfield_')) {
            const fields = await this.cacheManager.getAllFields();
            const customField = fields.find(field => field.id === fieldOperation.id);
            if (customField) {
                switch (customField.schema.custom) {
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiselect':
                        return this.processMultiOptionField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:select':
                        return this.processSingleOptionField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes':
                        return this.processMultiOptionField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:datepicker':
                        return this.processDateField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:datetime':
                        return this.processDateField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons':
                        return this.processSingleOptionField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:textarea':
                        return this.processTextAreaField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:userpicker':
                        return this.processUserPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker':
                        return this.processMultiGroupPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:grouppicker':
                        return this.processGroupPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:url':
                        return this.processURLField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:project':
                        return this.processProjectPickerField(fieldOperation, customField);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiuserpicker':
                        return this.processMultiUserPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiversion':
                        return this.processMultiVersionPickerField(fieldOperation);
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:version':
                        return this.processFieldWithID(fieldOperation);
                    case 'com.pyxis.greenhopper.jira:gh-epic-status':
                        return this.processFieldWithID(fieldOperation);
                }
            }
            else {
                throw new Error(`Custom field not found: ${fieldOperation.id}`);
            }
            return fieldOperation;
        }
        return fieldOperation;
    }
    async processProjectValue(fieldOperation) {
        if (fieldOperation.value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        try {
            const project = await this.cacheManager.getProject(fieldOperation.value);
            fieldOperation.value = { id: project.id.toString() };
            return fieldOperation;
        }
        catch (e) {
            fieldOperation.isErrorInProcessProjectValue = true;
            return fieldOperation;
        }
    }
    async processIssueType(fieldOperation) {
        const projectId = await this.waitForProjectToBeResolved();
        if (fieldOperation.value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        const issueTypes = await this.cacheManager.getAllIssueTypes();
        const issueType = issueTypes.find(issueType => {
            var _a, _b;
            return issueType.name.toLowerCase() === fieldOperation.value.toString().trim().toLowerCase()
                && !issueType.scope
                || ((_b = (_a = issueType.scope) === null || _a === void 0 ? void 0 : _a.project) === null || _b === void 0 ? void 0 : _b.id) === projectId;
        });
        if (issueType) {
            fieldOperation.value = { id: issueType.id.toString() };
        }
        else {
            throw new RequestValidationError([`Issue type not found: ${fieldOperation.value}`]);
        }
        return fieldOperation;
    }
    waitForProjectToBeResolved() {
        const getProjectId = () => {
            const project = this.fieldOperations.find(fo => fo.name === 'project');
            if (!project) {
                throw Error('Project must be specified.');
            }
            else if (project.isErrorInProcessProjectValue) {
                throw Error(`Project with the key '${project.value}' not found.`);
            }
            else if (typeof project.value.id === 'string') {
                return project.value.id;
            }
            else {
                return undefined;
            }
        };
        return new Promise((resolve, reject) => {
            let triesBeforeRejectCounter = 0;
            const checkIfProjectIsResolved = () => {
                if (triesBeforeRejectCounter < 100) {
                    triesBeforeRejectCounter++;
                }
                else {
                    reject('Project id not found.');
                    return;
                }
                try {
                    const projectId = getProjectId();
                    if (projectId) {
                        resolve(projectId);
                    }
                    else {
                        setTimeout(checkIfProjectIsResolved, 100);
                    }
                }
                catch (e) {
                    reject(e);
                }
            };
            checkIfProjectIsResolved();
        });
    }
    async processAssignee(fieldOperation) {
        if (fieldOperation.value.name) {
            return fieldOperation;
        }
        else {
            fieldOperation.value = { name: fieldOperation.value };
            return fieldOperation;
        }
    }
    async processSecurity(fieldOperation) {
        if (fieldOperation.value.id) {
            return fieldOperation;
        }
        else {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
    }
    async processMultiIDField(fieldOperation) {
        const convertedValues = [];
        const promises = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value.id) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { id: value.toString() };
            }
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async processPriority(fieldOperation) {
        if (fieldOperation.value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        const priorities = await this.cacheManager.getAllPriorities();
        const priority = priorities.find(priority => priority.name.toLowerCase() === fieldOperation.value.toString().trim().toLowerCase());
        if (priority) {
            fieldOperation.value = { id: priority.id.toString() };
        }
        else {
            throw new RequestValidationError([`Priority not found: ${fieldOperation.value}`]);
        }
        return fieldOperation;
    }
    async processResolution(fieldOperation) {
        if (fieldOperation.value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(fieldOperation.value)) {
            fieldOperation.value = { id: fieldOperation.value.toString() };
            return fieldOperation;
        }
        const resolutions = await this.cacheManager.getAllResolutions();
        const resolution = resolutions.find(resolution => resolution.name.toLowerCase() === fieldOperation.value.toString().trim().toLowerCase());
        if (resolution) {
            fieldOperation.value = { id: resolution.id.toString() };
        }
        else {
            throw new RequestValidationError([`Resolution not found: ${fieldOperation.value}`]);
        }
        return fieldOperation;
    }
    async processMultiOptionField(fieldOperation) {
        const convertedValues = [];
        const promises = [];
        (fieldOperation.value || []).forEach((value, index) => {
            const optionId = value.id ? value.id : value;
            promises.push(this.cacheManager.getCustomFieldOption(optionId).then(option => {
                if (option) {
                    if (value.id) {
                        convertedValues[index] = value;
                    }
                    else {
                        convertedValues[index] = { id: value.toString() };
                    }
                }
                else {
                    return Promise.reject(new RequestValidationError([`Custom field option not found: ${value}`]));
                }
                return Promise.resolve();
            }));
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async processSingleOptionField(fieldOperation) {
        const value = fieldOperation.value;
        let option;
        if (value.id) {
            option = await this.cacheManager.getCustomFieldOption(value.id);
            if (option) {
                return fieldOperation;
            }
            ;
        }
        else {
            option = await this.cacheManager.getCustomFieldOption(value);
            if (option) {
                fieldOperation.value = { id: value.toString() };
            }
        }
        return fieldOperation;
    }
    processDateField(fieldOperation) {
        const value = fieldOperation.value;
        if (value instanceof Date) {
            fieldOperation.value = value.toISOString();
        }
        return Promise.resolve(fieldOperation);
    }
    processTextAreaField(fieldOperation) {
        const value = fieldOperation.value;
        if (typeof value === 'string') {
            fieldOperation.value = value;
        }
        return Promise.resolve(fieldOperation);
    }
    processUserPickerField(fieldOperation) {
        const value = fieldOperation.value;
        if (value.accountId) {
            return Promise.resolve(fieldOperation);
        }
        fieldOperation.value = { accountId: value };
        return Promise.resolve(fieldOperation);
    }
    processGroupPickerField(fieldOperation) {
        const value = fieldOperation.value;
        if (value.name) {
            return Promise.resolve(fieldOperation);
        }
        fieldOperation.value = { name: value };
        return Promise.resolve(fieldOperation);
    }
    async processMultiGroupPickerField(fieldOperation) {
        const convertedValues = [];
        const promises = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value.name) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { name: value };
            }
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    processURLField(fieldOperation) {
        const value = fieldOperation.value;
        if (value instanceof URL) {
            fieldOperation.value = value.toString();
        }
        return Promise.resolve(fieldOperation);
    }
    async processProjectPickerField(fieldOperation, customField) {
        const value = fieldOperation.value;
        if (value.id) {
            return fieldOperation;
        }
        else if (looksLikeNumber(value)) {
            fieldOperation.value = { id: value.toString() };
            return fieldOperation;
        }
        else {
            const project = await this.cacheManager.getProject(value);
            if (project) {
                fieldOperation.value = { id: project.id.toString() };
            }
            else {
                throw new RequestValidationError([`Project not found - Custom Field: ${customField.name}(${customField.schema.customId}) - Project: ${value}`]);
            }
            return fieldOperation;
        }
    }
    processFieldWithID(fieldOperation) {
        const value = fieldOperation.value;
        if (value.id) {
            return Promise.resolve(fieldOperation);
        }
        fieldOperation.value = { id: value };
        return Promise.resolve(fieldOperation);
    }
    async processMultiVersionPickerField(fieldOperation) {
        const convertedValues = [];
        const promises = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value.id) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { id: value };
            }
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    async processMultiUserPickerField(fieldOperation) {
        const convertedValues = [];
        const promises = [];
        (fieldOperation.value || []).forEach((value, index) => {
            if (value.name) {
                convertedValues[index] = value;
            }
            else {
                convertedValues[index] = { name: value };
            }
        });
        await Promise.all(promises);
        fieldOperation.value = convertedValues;
        return fieldOperation;
    }
    setCustomField(customFieldIdOrName, value, updateOperation) {
        this.fieldOperations.push({
            name: customFieldIdOrName,
            value,
            updateOperation
        });
        return this.getNewInstance();
    }
    getNewInstance() {
        return new IssueBuilder(this.cacheManager, this.fieldOperations);
    }
}
