import { getIssueFields } from './handled-api/issue/field';
import { getProject } from './handled-api/project';
import { getIssueTypes } from './handled-api/issue/type';
import { getIssuePriorities } from './handled-api/issue/priority';
import { getIssueResolutions } from './handled-api/issue/resolution';
import { injectBuilders } from './handled-api/common';
import { ErrorStrategyBuilder } from './builder/errorStrategy';
import { getIssueCustomFieldOption } from './handled-api/issue/field/custom/option';
export class CacheManager {
    constructor(connection, options) {
        this.connection = connection;
        this.options = options;
        this.projects = new Map();
        this.customFieldOptions = new Map();
        if (!this.options) {
            this.options = {};
        }
        if (this.options.errorStrategy === undefined) {
            options = {
                errorStrategy: ErrorStrategyBuilder.create()
                    .retryOnRateLimiting()
                    .build()
            };
        }
    }
    clearCache() {
        this.fields = undefined;
        this.issueTypes = undefined;
        this.priorities = undefined;
        this.resolutions = undefined;
        this.projects = new Map();
    }
    getAllFields() {
        if (this.fields) {
            return Promise.resolve(this.fields);
        }
        else {
            return this.fetchAllFields();
        }
    }
    getAllIssueTypes() {
        if (this.issueTypes) {
            return Promise.resolve(this.issueTypes);
        }
        else {
            return this.fetchAllIssueTypes();
        }
    }
    getProject(projectKey) {
        if (this.projects.has(projectKey)) {
            return Promise.resolve(this.projects.get(projectKey));
        }
        else {
            return this.fetchProject(projectKey);
        }
    }
    getCustomFieldOption(fieldId) {
        if (this.customFieldOptions.has(fieldId)) {
            return Promise.resolve(this.customFieldOptions.get(fieldId));
        }
        else {
            return this.fetchCustomFieldOption(fieldId);
        }
    }
    getAllPriorities() {
        if (this.priorities) {
            return Promise.resolve(this.priorities);
        }
        else {
            return this.fetchAllPriorities();
        }
    }
    getAllResolutions() {
        if (this.resolutions) {
            return Promise.resolve(this.resolutions);
        }
        else {
            return this.fetchAllResolutions();
        }
    }
    async fetchAllFields() {
        const fields = await getIssueFields(injectBuilders({
            connectionId: this.connection,
            errorStrategy: this.options.errorStrategy
        }));
        this.fields = fields;
        return fields;
    }
    async fetchAllIssueTypes() {
        const issueTypes = await getIssueTypes(injectBuilders({
            connectionId: this.connection,
            errorStrategy: this.options.errorStrategy
        }));
        this.issueTypes = issueTypes;
        return issueTypes;
    }
    async fetchProject(projectKey) {
        const project = await getProject(injectBuilders({
            connectionId: this.connection,
            errorStrategy: this.options.errorStrategy,
            projectIdOrKey: projectKey
        }));
        this.projects.set(project.key, project);
        return project;
    }
    async fetchCustomFieldOption(fieldId) {
        const option = await getIssueCustomFieldOption({
            connectionId: this.connection,
            id: fieldId.toString(),
        });
        this.customFieldOptions.set(fieldId, option);
        return option;
    }
    async fetchAllPriorities() {
        const priorities = await getIssuePriorities(injectBuilders({
            connectionId: this.connection,
            errorStrategy: this.options.errorStrategy
        }));
        this.priorities = priorities;
        return priorities;
    }
    async fetchAllResolutions() {
        const resolutions = await getIssueResolutions(injectBuilders({
            connectionId: this.connection,
            errorStrategy: this.options.errorStrategy
        }));
        this.resolutions = resolutions;
        return resolutions;
    }
}
