import { BadRequestError, UnauthorizedError, ForbiddenError, NotFoundError, TooManyRequestsError, ServerError, HttpError, RequestValidationError, UnexpectedError, RetryRequested, delay, PropagationRequested } from '@avst-api/commons';
import { ErrorStrategyBuilder } from '../builder/errorStrategy';
export async function executeRequest(promise, errorHandlers, attempt = 1) {
    const currentStack = new Error().stack;
    const errorHandlersCopy = errorHandlers ? Object.assign({}, errorHandlers) : undefined; // Creating a shallow copy as the error handling methods will be progressively deleted when propagation is requested
    try {
        const res = await promise();
        if (res.ok) {
            return res.json();
        }
        else {
            const errors = await res.json();
            const err = mapStatusCodeToError(res, (errors && Array.isArray(errors.errorMessages)) ? errors.errorMessages.join(', ') : undefined);
            if (currentStack && err.stack) {
                err.stack = currentStack.replace('Error', err.stack.split('\n')[0]);
            }
            throw err;
        }
    }
    catch (originalError) {
        try {
            return handleError(originalError, attempt, errorHandlersCopy);
        }
        catch (error) {
            if (error instanceof RetryRequested) {
                await delay(error.delay);
                return executeRequest(promise, errorHandlers, ++attempt);
            }
            if (error instanceof PropagationRequested) {
                throw originalError;
            }
            throw error;
        }
    }
}
export function injectBuilders(options) {
    if (options && options.errorStrategy && typeof options.errorStrategy === 'function') {
        const response = options.errorStrategy(ErrorStrategyBuilder.create());
        if (response instanceof ErrorStrategyBuilder) {
            options.errorStrategy = response.build();
        }
        else {
            options.errorStrategy = response;
        }
    }
    return options;
}
function handleError(e, attempt, errorHandlers) {
    let error;
    if (!(e instanceof HttpError || e instanceof RequestValidationError)) {
        error = new UnexpectedError(e, e.toString ? e.toString() : 'Unexpected Error');
    }
    else {
        error = e;
    }
    let errorHandler = undefined;
    try {
        if (errorHandlers) {
            const { handleHttp400Error, handleHttp401Error, handleHttp403Error, handleHttp404Error, handleHttp429Error, handleHttp5xxError, handleHttpAnyError, handleUnexpectedError, handleAnyError } = errorHandlers;
            if (error instanceof HttpError) {
                if (error instanceof BadRequestError && handleHttp400Error) {
                    errorHandler = 'handleHttp400Error';
                    return handleErrorStrategyResponse(handleHttp400Error, error, attempt);
                }
                if (error instanceof UnauthorizedError && handleHttp401Error) {
                    errorHandler = 'handleHttp401Error';
                    return handleErrorStrategyResponse(handleHttp401Error, error, attempt);
                }
                if (error instanceof ForbiddenError && handleHttp403Error) {
                    errorHandler = 'handleHttp403Error';
                    return handleErrorStrategyResponse(handleHttp403Error, error, attempt);
                }
                if (error instanceof NotFoundError && handleHttp404Error) {
                    errorHandler = 'handleHttp404Error';
                    return handleErrorStrategyResponse(handleHttp404Error, error, attempt);
                }
                if (error instanceof TooManyRequestsError && handleHttp429Error) {
                    errorHandler = 'handleHttp429Error';
                    return handleErrorStrategyResponse(handleHttp429Error, error, attempt);
                }
                if (error instanceof ServerError && handleHttp5xxError) {
                    errorHandler = 'handleHttp5xxError';
                    return handleErrorStrategyResponse(handleHttp5xxError, error, attempt);
                }
                if (handleHttpAnyError) {
                    errorHandler = 'handleHttpAnyError';
                    return handleErrorStrategyResponse(handleHttpAnyError, error, attempt);
                }
            }
            if (error instanceof UnexpectedError && handleUnexpectedError) {
                errorHandler = 'handleUnexpectedError';
                return handleErrorStrategyResponse(handleUnexpectedError, error, attempt);
            }
            if (handleAnyError) {
                errorHandler = 'handleAnyError';
                return handleErrorStrategyResponse(handleAnyError, error, attempt);
            }
        }
    }
    catch (e) {
        if (e instanceof RetryRequested) {
            throw e;
        }
        if (e instanceof PropagationRequested) {
            if (e.skipErrorStrategyPropagation) {
                throw e;
            }
            if (errorHandler && errorHandlers) {
                delete errorHandlers[errorHandler]; // Delete the current callback method so when a propagation is allowed to progress then this error handler cannot be reached any longer
                return handleError(error, attempt, errorHandlers);
            }
        }
        return Promise.reject(e);
    }
    return Promise.reject(error);
}
function handleErrorStrategyResponse(callback, error, attempt) {
    const response = callback(error, attempt);
    if (response instanceof RetryRequested) {
        throw response;
    }
    if (response instanceof PropagationRequested) {
        throw response;
    }
    return Promise.resolve(response);
}
function mapStatusCodeToError(response, reason) {
    const fetchId = response.headers.get('x-hzn-fetch-id');
    switch (response.status) {
        case 400:
            return new BadRequestError(response, getMessage(response.status, reason, fetchId));
        case 401:
            return new UnauthorizedError(response, getMessage(response.status, reason, fetchId));
        case 403:
            return new ForbiddenError(response, getMessage(response.status, reason, fetchId));
        case 404:
            return new NotFoundError(response, getMessage(response.status, reason, fetchId));
        case 429:
            return new TooManyRequestsError(response, getMessage(response.status, reason, fetchId));
        case 500:
        case 501:
        case 502:
        case 503:
        case 504:
        case 505:
            return new ServerError(response, getMessage(response.status, reason, fetchId));
        default:
            return new HttpError(response, getMessage(response.status, reason, fetchId), 'ClientError');
    }
}
function getMessage(statusCode, reason, fetchId) {
    let message = `Unexpected HTTP response: ${statusCode}`;
    if (fetchId) {
        message += ` - Fetch ID: ${fetchId}`;
    }
    if (reason) {
        message += ` - Reason: ${reason}`;
    }
    return message;
}
