import { executeRequest } from './common';
import { getProjects as getProjectsFn, createProject as createProjectFn, getProject as getProjectFn, updateProject as updateProjectFn, deleteProject as deleteProjectFn, archiveProject as archiveProjectFn, getProjectComponents as getProjectComponentsFn, restoreProject as restoreProjectFn, getProjectStatuses as getProjectStatusesFn, updateProjectType as updateProjectTypeFn, getProjectVersionsPaginated as getProjectVersionsPaginatedFn, getProjectVersions as getProjectVersionsFn } from '../raw-api/project';
/**
 * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllProjects
 * @param options Request options.
 */
export function getProjects(options) {
    return executeRequest(() => getProjectsFn(options), options.errorStrategy);
}
/**
 * Creates a new project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-createProject
 * @param options Request options.
 */
export function createProject(options) {
    return executeRequest(() => createProjectFn(options), options.errorStrategy);
}
/**
 * Contains a full representation of a project in JSON format.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProject
 * @param options Request options.
 */
export function getProject(options) {
    return executeRequest(() => getProjectFn(options), options.errorStrategy);
}
/**
 * Updates a project. Only non null values sent in JSON will be updated in the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProject
 * @param options Request options.
 */
export function updateProject(options) {
    return executeRequest(() => updateProjectFn(options), options.errorStrategy);
}
/**
 * Deletes a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-deleteProject
 * @param options Request options.
 */
export function deleteProject(options) {
    return executeRequest(() => deleteProjectFn(options), options.errorStrategy);
}
/**
 * Archives a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-archiveProject
 * @param options Request options.
 */
export function archiveProject(options) {
    return executeRequest(() => archiveProjectFn(options), options.errorStrategy);
}
/**
 * Contains a full representation of a the specified project's components.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectComponents
 * @param options Request options.
 */
export function getProjectComponents(options) {
    return executeRequest(() => getProjectComponentsFn(options), options.errorStrategy);
}
/**
 * Restore an archived project. In case of success restored project should be re-indexed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-restoreProject
 * @param options Request options.
 */
export function restoreProject(options) {
    return executeRequest(() => restoreProjectFn(options), options.errorStrategy);
}
/**
 * Get all issue types with valid status values for a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllStatuses
 * @param options Request options.
 */
export function getProjectStatuses(options) {
    return executeRequest(() => getProjectStatusesFn(options), options.errorStrategy);
}
/**
 * Updates the type of a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProjectType
 * @param options Request options.
 */
export function updateProjectType(options) {
    return executeRequest(() => updateProjectTypeFn(options), options.errorStrategy);
}
/**
 * Returns all versions for the specified project. Results are paginated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersionsPaginated
 * @param options Request options.
 */
export function getProjectVersionsPaginated(options) {
    return executeRequest(() => getProjectVersionsPaginatedFn(options), options.errorStrategy);
}
/**
 * Contains a full representation of a the specified project's versions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersions
 * @param options Request options.
 */
export function getProjectVersions(options) {
    return executeRequest(() => getProjectVersionsFn(options), options.errorStrategy);
}
