/// <reference types="runtime" />
import { Issue } from './types/issue';
import { Group } from './types/group';
import { Filter } from './types/filter';
import { Instance } from './types/instance';
import { Project } from './types/project';
import { Myself } from './types/myself';
import { Workflow } from './types/workflow';
import { User } from './types/user';
import { Role } from './types/role';
import { Permission } from './types/permission';
import { Dashboard } from './types/dashboard';
import { Scheme } from './types/scheme';
import { ErrorStrategyBuilder } from './builder/errorStrategy';
import { AssistedErrorStrategyOption, ErrorStrategyHandlers, AssistedErrorStrategyFunction } from './handled-api/common';
import { IssueHelper } from './helper/issue';
import { ManagedIssue } from './common';
interface ConnectionOptions extends AssistedErrorStrategyOption {
}
export declare namespace JiraServerConnection {
    function connect(instanceId: string, options?: ConnectionOptions): JiraServerInstance;
}
export declare class JiraServerInstance {
    protected issueHelper: IssueHelper;
    All: AllGroup;
    Builders: BuildersGroup;
    Issue: IssueGroup;
    Filter: FilterGroup;
    Group: GroupGroup;
    Instance: InstanceGroup;
    Project: ProjectGroup;
    Myself: MyselfGroup;
    Workflow: WorkflowGroup;
    User: UserGroup;
    Role: RoleGroup;
    Permission: PermissionGroup;
    Dashboard: DashboardGroup;
    Scheme: SchemeGroup;
    private connection;
    constructor(connection: string, options?: ConnectionOptions);
    /**
     * Performs fetch call using managed connection.
     */
    fetch<T = any>(url: string, options?: RequestInit): Promise<Response<T>>;
    /**
     * Set global error strategy.
     */
    setGlobalErrorStrategy(errorStrategy?: ErrorStrategyHandlers | AssistedErrorStrategyFunction | null): void;
}
declare class BaseGroup {
    protected connection: string;
    protected options: ConnectionOptions;
    constructor(connection: string, options: ConnectionOptions);
    protected getOptions(options: any): any;
}
declare class AllGroup extends BaseGroup {
    private issueHelper;
    constructor(connection: string, options: ConnectionOptions, issueHelper: IssueHelper);
    /**
     * Create a new issue link type.
     * Recommended usage: Issue.Link.Type.createType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-createIssueLinkType
     * @param options Request options.
     */
    createIssueLinkType<T = Issue.Link.Type.CreateType.Response.OK>(options: Issue.Link.Type.CreateType.Options): Promise<import("./definitions/issue_link_type").IssueLinkType>;
    /**
     * Delete the specified issue link type.
     * Recommended usage: Issue.Link.Type.deleteType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-deleteIssueLinkType
     * @param options Request options.
     */
    deleteIssueLinkType<T = Issue.Link.Type.DeleteType.Response.OK>(options: Issue.Link.Type.DeleteType.Options): Promise<undefined>;
    /**
     * Update the specified issue link type.
     * Recommended usage: Issue.Link.Type.updateType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-updateIssueLinkType
     * @param options Request options.
     */
    updateIssueLinkType<T = Issue.Link.Type.UpdateType.Response.OK>(options: Issue.Link.Type.UpdateType.Options): Promise<import("./definitions/issue_link_type").IssueLinkType>;
    /**
     * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
     * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
     * Recommended usage: Issue.Type.getAlternativeTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getAlternativeIssueTypes
     * @param options Request options.
     */
    getAlternativeIssueTypes<T = Issue.Type.GetAlternativeTypes.Response.OK>(options: Issue.Type.GetAlternativeTypes.Options): Promise<Issue.Type.GetAlternativeTypes.Response.OK>;
    /**
     * Updates the specified issue type from a JSON representation.
     * Recommended usage: Issue.Type.updateType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-updateIssueType
     * @param options Request options.
     */
    updateIssueType<T = Issue.Type.UpdateType.Response.OK>(options: Issue.Type.UpdateType.Options): Promise<import("./definitions/issue_type").IssueType>;
    /**
     * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
     * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
     * Recommended usage: Issue.Type.deleteType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-deleteIssueType
     * @param options Request options.
     */
    deleteIssueType<T = Issue.Type.DeleteType.Response.OK>(options: Issue.Type.DeleteType.Options): Promise<undefined>;
    /**
     * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
     * Recommended usage: Issue.Type.createType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-createIssueType
     * @param options Request options.
     */
    createIssueType<T = Issue.Type.CreateType.Response.OK>(options: Issue.Type.CreateType.Options): Promise<import("./definitions/issue_type").IssueType>;
    /**
     * Returns the default share scope of the logged-in user.
     * Recommended usage: Filter.Share.getShareScope
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getDefaultShareScope
     * @param options Request options.
     */
    getDefaultShareScope<T = Filter.Share.GetDefaultScope.Response.OK>(options?: Filter.Share.GetDefaultScope.Options): Promise<Filter.Share.GetDefaultScope.Response.OK>;
    /**
     * Sets the default share scope of the logged-in user. Available values are GLOBAL and PRIVATE.
     * Recommended usage: Filter.Share.setShareScope
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setDefaultShareScope
     * @param options Request options.
     */
    setDefaultShareScope<T = Filter.Share.SetDefaultScope.Response.OK>(options: Filter.Share.SetDefaultScope.Options): Promise<Filter.Share.SetDefaultScope.Response.OK>;
    /**
     * Removes a share permissions from the given filter.
     * Recommended usage: Filter.Share.Permission.deleteSharePermission
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
     * @param options Request options.
     */
    deleteFilterSharePermission<T = Filter.Share.Permission.DeleteSharePermission.Response.OK>(options: Filter.Share.Permission.DeleteSharePermission.Options): Promise<undefined>;
    /**
     * Returns a single share permission of the given filter.
     * Recommended usage: Filter.Share.Permission.getSharePermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
     * @param options Request options.
     */
    getFilterSharePermission<T = Filter.Share.Permission.GetSharePermission.Response.OK>(options: Filter.Share.Permission.GetSharePermission.Options): Promise<import("./definitions/filter").FilterPermission>;
    /**
     * Adds a share permissions to the given filter. Adding a global permission removes all previous permissions from the filter.
     * Recommended usage: Filter.Share.Permission.addSharePermission
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-addSharePermission
     * @param options Request options.
     */
    addFilterSharePermission<T = Filter.Share.Permission.AddSharePermissions.Response.OK>(options: Filter.Share.Permission.AddSharePermissions.Options): Promise<Filter.Share.Permission.AddSharePermissions.Response.OK>;
    /**
     * Resets the columns for the given filter such that the filter no longer has its own column config.
     * Recommended usage: Filter.Column.resetColumns
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-resetColumns
     * @param options Request options.
     */
    resetFilterColumns<T = Filter.Column.ResetColumns.Response.OK>(options: Filter.Column.ResetColumns.Options): Promise<undefined>;
    /**
     * Sets the default columns for the given filter.
     * Recommended usage: Filter.Column.setDefaultColumns
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setColumns
     * @param options Request options.
     */
    setFilterDefaultColumns<T = Filter.Column.SetDefaultColumns.Response.OK>(options: Filter.Column.SetDefaultColumns.Options): Promise<undefined>;
    /**
     * Returns the default columns for the given filter. Currently logged in user will be used as the user making such request.
     * Recommended usage: Filter.Column.getDefaultColumns
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-defaultColumns
     * @param options Request options.
     */
    getFilterDefaultColumns<T = Filter.Column.GetDefaultColumns.Response.OK>(options: Filter.Column.GetDefaultColumns.Options): Promise<Filter.Column.GetDefaultColumns.Response.OK>;
    /**
     * Delete a filter.
     * Recommended usage: Filter.deleteFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-deleteFilter
     * @param options Request options.
     */
    deleteFilter<T = Filter.DeleteFilter.Response.OK>(options: Filter.DeleteFilter.Options): Promise<undefined>;
    /**
     * Updates an existing filter, and returns its new value.
     * Recommended usage: Filter.editFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-editFilter
     * @param options Request options.
     */
    editFilter<T = Filter.EditFilter.Response.OK>(options: Filter.EditFilter.Options): Promise<import("./definitions/filter").Filter>;
    /**
     * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
     * Recommended usage: Filter.createFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-createFilter
     * @param options Request options.
     */
    createFilter<T = Filter.CreateFilter.Response.OK>(options: Filter.CreateFilter.Options): Promise<import("./definitions/filter").Filter>;
    /**
     * Returns all workflows.
     * Recommended usage: Workflow.getWorkflows
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/workflow-getAllWorkflows
     * @param options Request options.
     */
    getWorkflows<T = Workflow.GetWorkflows.Response.OK>(options?: Workflow.GetWorkflows.Options): Promise<Workflow.GetWorkflows.Response.OK>;
    /**
     * Returns a paginated list of notification schemes.
     * Recommended usage: Scheme.Notification.getSchemes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/notificationscheme-getNotificationSchemes
     * @param options Request options.
     */
    getNotificationSchemes<T = Scheme.Notification.GetSchemes.Response.OK>(options?: Scheme.Notification.GetSchemes.Options): Promise<Scheme.Notification.GetSchemes.Response.OK>;
    /**
     * Returns the favourite filters of the logged-in user.
     * Recommended usage: Filter.getMyFavouriteFilters
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFavouriteFilters
     * @param options Request options.
     */
    getMyFavouriteFilters<T = Filter.GetMyFavouriteFilters.Response.OK>(options?: Filter.GetMyFavouriteFilters.Options): Promise<Filter.GetMyFavouriteFilters.Response.OK>;
    /**
     * Returns all share permissions of the given filter.
     * Recommended usage: Filter.Share.Permission.getSharePermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermissions
     * @param options Request options.
     */
    getFilterSharePermissions<T = Filter.Share.Permission.GetSharePermissions.Response.OK>(options: Filter.Share.Permission.GetSharePermissions.Options): Promise<Filter.Share.Permission.GetSharePermissions.Response.OK>;
    /**
     * Returns a list of all dashboards, optionally filtering them.
     * Recommended usage: Dashboard.getDashboards
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-list
     * @param options Request options.
     */
    getAllDashboards<T = Dashboard.GetDashboards.Response.OK>(options?: Dashboard.GetDashboards.Options): Promise<import("./definitions/dashboard").Dashboards>;
    /**
     * Returns a single dashboard.
     * Recommended usage: Dashboard.getDashboard
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-getDashboard
     * @param options Request options.
     */
    getDashboardById<T = Dashboard.GetDashboard.Response.OK>(options: Dashboard.GetDashboard.Options): Promise<import("./definitions/dashboard").Dashboard>;
    /**
     * Returns all permissions in the system and whether the currently logged in user has them.
     * You can optionally provide a specific context to get permissions for (projectKey OR projectId OR issueKey OR issueId).
     * Recommended usage: Permission.getMyPermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getPermissions
     * @param options Request options.
     */
    getMyPermissions<T = Permission.GetMyPermissions.Response.OK>(options?: Permission.GetMyPermissions.Options): Promise<import("./definitions/permissions").Permissions>;
    /**
     * Returns all permissions that are present in the JIRA instance - Global, Project and the global ones added by plugins
     * Recommended usage: Permission.getPermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getAllPermissions
     * @param options Request options.
     */
    getPermissions<T = Permission.GetPermissions.Response.OK>(options?: Permission.GetPermissions.Options): Promise<import("./definitions/permissions").Permissions>;
    /**
     * Get a list of the transitions possible for this issue by the current user, along with fields that are required and their types.
     * Fields will only be returned if expand=transitions.fields.
     * The fields in the metadata correspond to the fields in the transition screen for that transition. Fields not in the screen will not be in the metadata.
     * Recommended usage: Issue.Transition.getTransitions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getTransitions
     * @param options Request options.
     */
    getIssueTransitions<T = Issue.Transition.GetTransitions.Response.OK>(options: Issue.Transition.GetTransitions.Options): Promise<Issue.Transition.GetTransitions.Response.OK>;
    /**
     * Perform a transition on an issue. When performing the transition you can update or set other issue fields.
     * The fields that can be set on transtion, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/{issueIdOrKey}/transitions?expand=transitions.fields resource. If a field is not configured to appear on the transition screen, then it will not be in the transition metadata, and a field validation error will occur if it is submitted. The updateHistory param adds the issues retrieved by this method to the current user's issue history, if set to true (by default, the issue history does not include issues retrieved via the REST API). You can view the issue history in the JIRA application, via the Issues dropdown or by using the lastViewed JQL field in an issue search.
     * Recommended usage: Issue.Transition.performTransition
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-doTransition
     * @param options Request options.
     */
    performIssueTransition<T = Issue.Transition.PerformTransition.Response.OK>(options: Issue.Transition.PerformTransition.Options): Promise<undefined>;
    /**
     * Returns an issue's subtask list.
     * Recommended usage: Issue.SubTask.getSubTasks
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-getSubTasks
     * @param options Request options.
     */
    getIssueSubTasks<T = Issue.SubTask.GetSubTasks.Response.OK>(options: Issue.SubTask.GetSubTasks.Options): Promise<Issue.SubTask.GetSubTasks.Response.OK>;
    /**
     * Returns the information if the optional features in JIRA are enabled or disabled. If the time tracking is enabled, it also returns the detailed information about time tracking configuration.
     * Recommended: Instance.getConfiguration
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/configuration-getConfiguration
     * @param options Request options.
     */
    getInstanceConfiguration<T = Instance.GetConfiguration.Response.OK>(options?: Instance.GetConfiguration.Options): Promise<import("./definitions/instance").GetConfigurationResponse>;
    /**
     * Returns a full representation of the Custom Field Option that has the given id.
     * Recommended: Issue.Field.Custom.Option.getOption
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/customFieldOption-getCustomFieldOption
     * @param options Request options.
     */
    getIssueCustomFieldOption<T = Issue.Field.Custom.Option.GetOption.Response.OK>(options: Issue.Field.Custom.Option.GetOption.Options): Promise<Issue.Field.Custom.Option.GetOption.Response.OK>;
    /**
     * Recommended usage: Issue.SubTask.canMoveSubTask
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-canMoveSubTask
     * @param options Request options.
     */
    canMoveIssueSubTask<T = Issue.SubTask.CanMoveSubTask.Response.OK>(options: Issue.SubTask.CanMoveSubTask.Options): Promise<boolean>;
    /**
     * Reorders an issue's subtasks by moving the subtask at index "from" to index "to".
     * Recommended usage: Issue.SubTask.moveSubTasks
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-moveSubTasks
     * @param options Request options.
     */
    moveIssueSubTasks<T = Issue.SubTask.MoveSubTasks.Response.OK>(options: Issue.SubTask.MoveSubTasks.Options): Promise<undefined>;
    /**
     * Creates an issue link between two issues. The user requires the link issue permission for the issue which will be linked to another issue. The specified link type in the request is used to create the link and will create a link from the first issue to the second issue using the outward description. It also create a link from the second issue to the first issue using the inward description of the issue link type. It will add the supplied comment to the first issue. The comment can have a restriction who can view it. If group is specified, only users of this group can view this comment, if roleLevel is specified only users who have the specified role can view this comment. The user who creates the issue link needs to belong to the specified group or have the specified role.
     * Recommended usage: Issue.Link.createLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-linkIssues
     * @param options Request options.
     */
    createIssueLink<T = Issue.Link.CreateLink.Response.OK>(options: Issue.Link.CreateLink.Options): Promise<undefined>;
    /**
     * Returns an issue link with the specified id.
     * Recommended usage: Issue.Link.getLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-getIssueLink
     * @param options Request options.
     */
    getIssueLink<T = Issue.Link.GetLink.Response.OK>(options: Issue.Link.GetLink.Options): Promise<Issue.Link.GetLink.Response.OK>;
    /**
     * Deletes an issue link with the specified id. To be able to delete an issue link you must be able to view both issues and must have the link issue permission for at least one of the issues.
     * Recommended usage: Issue.Link.deleteLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-deleteIssueLink
     * @param options Request options.
     */
    deleteIssueLink<T = Issue.Link.DeleteLink.Response.OK>(options: Issue.Link.DeleteLink.Options): Promise<undefined>;
    /**
     * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
     * Recommended usage: Issue.Link.Type.getTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkTypes
     * @param options Request options.
     */
    getIssueLinkTypes<T = Issue.Link.Type.GetTypes.Response.OK>(options?: Issue.Link.Type.GetTypes.Options): Promise<Issue.Link.Type.GetTypes.Response.OK>;
    /**
     * Returns for a given issue link type id all information about this issue link type.
     * Recommended usage: Issue.Link.Type.getType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkType
     * @param options Request options.
     */
    getIssueLinkType<T = Issue.Link.Type.GetType.Response.OK>(options: Issue.Link.Type.GetType.Options): Promise<import("./definitions/issue_link_type").IssueLinkType>;
    /**
     * Creates a group by given group parameter.
     * Recommended usage: Group.createGroup
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-createGroup
     * @param options Request options.
     */
    createGroup<T = Group.CreateGroup.Response.OK>(options: Group.CreateGroup.Options): Promise<import("./definitions/group").GroupResponse>;
    /**
     * Deletes a group by given group parameter.
     * Recommended usage: Group.removeGroup
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeGroup
     * @param options Request options.
     */
    removeGroup<T = Group.RemoveGroup.Response.OK>(options: Group.RemoveGroup.Options): Promise<undefined>;
    /**
     * This resource returns a paginated list of users who are members of the specified group and its subgroups. Users in the page are ordered by user names. User of this resource is required to have sysadmin or admin permissions.
     * Recommended usage: Group.User.getUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-getUsersFromGroup
     * @param options Request options.
     */
    getUsersFromGroup<T = Group.User.GetUsers.Response.OK>(options: Group.User.GetUsers.Options): Promise<import("./definitions/group").GetUsersResponse>;
    /**
     * Adds given user to a group.
     * Recommended usage: Group.User.addUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-addUserToGroup
     * @param options Request options.
     */
    addUsersToGroup<T = Group.User.AddUsers.Response.OK>(options: Group.User.AddUsers.Options): Promise<import("./definitions/group").GroupResponse>;
    /**
     * Removes given user from a group.
     * Recommended usage: Group.User.removeUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeUserFromGroup
     * @param options Request options.
     */
    removeUsersFromGroup<T = Group.User.RemoveUsers.Response.OK>(options: Group.User.RemoveUsers.Options): Promise<undefined>;
    /**
     * Returns a filter given an id.
     * Recommended usage: Filter.getFilter
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFilter
     * @param options Request options.
     */
    getFilter<T = Filter.GetFilter.Response.OK>(options: Filter.GetFilter.Options): Promise<import("./definitions/filter").Filter>;
    /**
     * Returns a list of all fields, both System and Custom.
     * Recommended usage: Issue.Field.getFields
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/field-getFields
     * @param options Request options.
     */
    getIssueFields<T = Issue.Field.GetFields.Response.OK>(options?: Issue.Field.GetFields.Options): Promise<Issue.Field.GetFields.Response.OK>;
    /**
     * Recommended: Issue.Field.Custom.getFields
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/customFields-getCustomFields
     * @param options Request options.
     */
    getIssueCustomFields<T = Issue.Field.Custom.GetFields.Response.OK>(options?: Issue.Field.Custom.GetFields.Options): Promise<Issue.Field.Custom.GetFields.Response.OK>;
    /**
     * Creates an issue or a sub-task from a JSON representation.
     * The fields that can be set on create, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/createmeta resource. If a field is not configured to appear on the create screen, then it will not be in the createmeta, and a field validation error will occur if it is submitted.
     * Creating a sub-task is similar to creating a regular issue, with two important differences:
     * the issueType field must correspond to a sub-task issue type (you can use /issue/createmeta to discover sub-task issue types), and you must provide a parent field in the issue create request containing the id or key of the parent issue.
     * Recommended usage: Issue.createIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createIssue
     * @param options Request options.
     */
    createIssue<T = Issue.CreateIssue.Response.OK>(options: Issue.CreateIssue.Options): Promise<Issue.CreateIssue.Response.OK>;
    /**
     * Delete an issue. If the issue has subtasks you must set the parameter deleteSubtasks=true to delete the issue. You cannot delete an issue without its subtasks also being deleted.
     * Recommended usage: Issue.deleteIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteIssue
     * @param options Request options.
     */
    deleteIssue<T = Issue.DeleteIssue.Response.OK>(options: Issue.DeleteIssue.Options): Promise<undefined>;
    /**
     * Returns a full representation of the issue for the given issue key.
     * JIRA will attempt to identify the issue by the issueIdOrKey path parameter. This can be an issue id, or an issue key. If the issue cannot be found via an exact match, JIRA will also look for the issue in a case-insensitive way, or by looking to see if the issue was moved. In either of these cases, the request will proceed as normal (a 302 or other redirect will not be returned). The issue key contained in the response will indicate the current value of issue's key.
     * Recommended usage: Issue.getIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssue
     * @param options Request options.
     */
    getIssue<T = ManagedIssue.Read.Response>(options: Issue.GetIssue.Options): Promise<ManagedIssue.Read.Response | T>;
    /**
     * Edits an issue from a JSON representation.
     * The issue can either be updated by setting explicit the field value(s) or by using an operation to change the field value.
     * The fields that can be updated, in either the fields parameter or the update parameter, can be determined using the /rest/api/2/issue/{issueIdOrKey}/editmeta resource.
     * If a field is not configured to appear on the edit screen, then it will not be in the editmeta, and a field validation error will occur if it is submitted.
     * Specifying a "field_id": field_value in the "fields" is a shorthand for a "set" operation in the "update" section.
     * Field should appear either in "fields" or "update", not in both.
     * Recommended usage: Issue.editIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-editIssue
     * @param options Request options.
     */
    editIssue<T = Issue.EditIssue.Response.OK>(options: Issue.EditIssue.Options): Promise<undefined>;
    /**
     * Assigns an issue to a user. You can use this resource to assign issues when the user submitting the request has the assign permission but not the edit issue permission. If the name is "-1" automatic assignee is used. A null name will remove the assignee.
     * Recommended usage: Issue.assignIssue
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-assign
     * @param options Request options.
     */
    assignIssue<T = Issue.AssignIssue.Response.OK>(options: Issue.AssignIssue.Options): Promise<undefined>;
    /**
     * Returns all comments for an issue.
     * Recommended usage: Issue.Comment.getComments
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComments
     * @param options Request options.
     */
    getIssueComments<T = Issue.Comment.GetComments.Response.OK>(options: Issue.Comment.GetComments.Options): Promise<Issue.Comment.GetComments.Response.OK>;
    /**
     * Adds a new comment to an issue.
     * Recommended usage: Issue.Comment.addComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addComment
     * @param options Request options.
     */
    addIssueComment<T = Issue.Comment.AddComment.Response.OK>(options: Issue.Comment.AddComment.Options): Promise<import("./definitions/comment").Comment>;
    /**
     * Returns a single comment.
     * Recommended usage: Issue.Comment.getComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComment
     * @param options Request options.
     */
    getIssueComment<T = Issue.Comment.GetComment.Response.OK>(options: Issue.Comment.GetComment.Options): Promise<import("./definitions/comment").Comment>;
    /**
     * Updates an existing comment using its JSON representation.
     * Recommended usage: Issue.Comment.updateComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateComment
     * @param options Request options.
     */
    updateIssueComment<T = Issue.Comment.UpdateComment.Response.OK>(options: Issue.Comment.UpdateComment.Options): Promise<import("./definitions/comment").Comment>;
    /**
     * Deletes an existing comment.
     * Recommended usage: Issue.Comment.deleteComment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteComment
     * @param options Request options.
     */
    deleteIssueComment<T = Issue.Comment.DeleteComment.Response.OK>(options: Issue.Comment.DeleteComment.Options): Promise<undefined>;
    /**
     * Returns the meta data for editing an issue. The fields in the editmeta correspond to the fields in the edit screen for the issue. Fields not in the screen will not be in the editmeta.
     * Recommended usage: Issue.Metadata.getEditMetadata
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getEditIssueMeta
     * @param options Request options.
     */
    getEditIssueMetadata<T = Issue.Metadata.GetEditMetadata.Response.OK>(options: Issue.Metadata.GetEditMetadata.Options): Promise<Issue.Metadata.GetEditMetadata.Response.OK>;
    /**
     * Sends a notification (email) to the list or recipients defined in the request.
     * Recommended usage: Issue.sendNotification
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-notify
     * @param options Request options.
     */
    sendNotificationForIssue<T = Issue.SendNotification.Response.OK>(options: Issue.SendNotification.Options): Promise<undefined>;
    /**
     * A REST sub-resource representing the remote issue links on the issue.
     * Recommended usage: Issue.Link.Remote.getLinks
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinks
     * @param options Request options.
     */
    getRemoteIssueLinks<T = Issue.Link.Remote.GetLinks.Response.OK>(options: Issue.Link.Remote.GetLinks.Options): Promise<Issue.Link.Remote.GetLinks.Response.OK>;
    /**
     * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
     * Recommended usage: Issue.Link.Remote.createOrUpdateLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createOrUpdateRemoteIssueLink
     * @param options Request options.
     */
    createOrUpdateRemoteIssueLink<T = Issue.Link.Remote.CreateOrUpdateLink.Response.OK>(options: Issue.Link.Remote.CreateOrUpdateLink.Options): Promise<Issue.Link.Remote.CreateOrUpdateLink.Response.OK>;
    /**
     * Delete the remote issue link with the given global id on the issue.
     * Recommended usage: Issue.Link.Remote.deleteLinkByGlobalId
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkByGlobalId
     * @param options Request options.
     */
    deleteRemoteIssueLinkByGlobalId<T = Issue.Link.Remote.DeleteLinkByGlobalId.Response.OK>(options: Issue.Link.Remote.DeleteLinkByGlobalId.Options): Promise<undefined>;
    /**
     * Get the remote issue link with the given id on the issue.
     * Recommended usage: Issue.Link.Remote.getLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinkById
     * @param options Request options.
     */
    getRemoteIssueLink<T = Issue.Link.Remote.GetLink.Response.OK>(options: Issue.Link.Remote.GetLink.Options): Promise<Issue.Link.Remote.GetLink.Response.OK>;
    /**
     * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
     * Recommended usage: Issue.Link.Remote.updateLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateRemoteIssueLink
     * @param options Request options.
     */
    updateRemoteIssueLink<T = Issue.Link.Remote.UpdateLink.Response.OK>(options: Issue.Link.Remote.UpdateLink.Options): Promise<undefined>;
    /**
     * Delete the remote issue link with the given id on the issue.
     * Recommended usage: Issue.Link.Remote.deleteLink
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkById
     * @param options Request options.
     */
    deleteRemoteIssueLink<T = Issue.Link.Remote.DeleteLink.Response.OK>(options: Issue.Link.Remote.DeleteLink.Options): Promise<undefined>;
    /**
     * Remove your vote from an issue. (i.e. "unvote").
     * Recommended usage: Issue.Vote.removeVote
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeVote
     * @param options Request options.
     */
    removeIssueVote<T = Issue.Vote.RemoveVote.Response.OK>(options: Issue.Vote.RemoveVote.Options): Promise<undefined>;
    /**
     * Cast your vote in favour of an issue.
     * Recommended usage: Issue.Vote.addVote
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addVote
     * @param options Request options.
     */
    addIssueVote<T = Issue.Vote.AddVote.Response.OK>(options: Issue.Vote.AddVote.Options): Promise<undefined>;
    /**
     * A REST sub-resource representing the voters on the issue.
     * Recommended usage: Issue.Vote.getVotes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getVotes
     * @param options Request options.
     */
    getIssueVotes<T = Issue.Vote.GetVotes.Response.OK>(options: Issue.Vote.GetVotes.Options): Promise<Issue.Vote.GetVotes.Response.OK>;
    /**
     * Returns the list of watchers for the issue with the given key.
     * Recommended usage: Issue.Watcher.getWatchers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWatchers
     * @param options Request options.
     */
    getIssueWatchers<T = Issue.Watcher.GetWatchers.Response.OK>(options: Issue.Watcher.GetWatchers.Options): Promise<Issue.Watcher.GetWatchers.Response.OK>;
    /**
     * Adds a user to an issue's watcher list.
     * Recommended usage: Issue.Watcher.addWatcher
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWatcher
     * @param options Request options.
     */
    addIssueWatcher<T = Issue.Watcher.AddWatcher.Response.OK>(options: Issue.Watcher.AddWatcher.Options): Promise<undefined>;
    /**
     * Removes a user from an issue's watcher list.
     * Recommended usage: Issue.Watcher.removeWatcher
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeWatcher
     * @param options Request options.
     */
    removeIssueWatcher<T = Issue.Watcher.RemoveWatcher.Response.OK>(options: Issue.Watcher.RemoveWatcher.Options): Promise<undefined>;
    /**
     * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
     * Recommended usage: Issue.Worklog.getWorklogs
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWorklog
     * @param options Request options.
     */
    getIssueWorklogs<T = Issue.Worklog.GetWorklogs.Response.OK>(options: Issue.Worklog.GetWorklogs.Options): Promise<Issue.Worklog.GetWorklogs.Response.OK>;
    /**
     * Adds a new worklog entry to an issue.
     * Recommended usage: Issue.Worklog.addWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWorklog
     * @param options Request options.
     */
    addIssueWorklog<T = Issue.Worklog.AddWorklog.Response.OK>(options: Issue.Worklog.AddWorklog.Options): Promise<import("./definitions/worklog").Worklog>;
    /**
     * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
     * Recommended usage: Issue.Worklog.getWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getWorklog
     * @param options Request options.
     */
    getIssueWorklog<T = Issue.Worklog.GetWorklog.Response.OK>(options: Issue.Worklog.GetWorklog.Options): Promise<import("./definitions/worklog").Worklog>;
    /**
     * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
     * Recommended usage: Issue.Worklog.updateWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateWorklog
     * @param options Request options.
     */
    updateIssueWorklog<T = Issue.Worklog.UpdateWorklog.Response.OK>(options: Issue.Worklog.UpdateWorklog.Options): Promise<import("./definitions/worklog").Worklog>;
    /**
     * Deletes an existing worklog entry.
     * Recommended usage: Issue.Worklog.deleteWorklog
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteWorklog
     * @param options Request options.
     */
    deleteIssueWorklog<T = Issue.Worklog.DeleteWorklog.Response.OK>(options: Issue.Worklog.DeleteWorklog.Options): Promise<undefined>;
    /**
     * Returns the meta data for creating issues. This includes the available projects, issue types and fields, including field types and whether or not those fields are required. Projects will not be returned if the user does not have permission to create issues in that project.
     * The fields in the createmeta correspond to the fields in the create screen for the project/issuetype. Fields not in the screen will not be in the createmeta.
     * Fields will only be returned if expand=projects.issuetypes.fields.
     * The results can be filtered by project and/or issue type, given by the query params.
     * Recommended usage: Issue.Metadata.getCreateMetadata
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getCreateIssueMeta
     * @param options Request options.
     */
    getCreateIssueMetadata<T = Issue.Metadata.GetCreateMetadata.Response.OK>(options?: Issue.Metadata.GetCreateMetadata.Options): Promise<Issue.Metadata.GetCreateMetadata.Response.OK>;
    /**
     * Returns an application property.
     * Recommended usage: Instance.getApplicationProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getProperty
     * @param options Request options.
     */
    getApplicationProperty<T = Instance.GetApplicationProperty.Response.OK>(options?: Instance.GetApplicationProperty.Options): Promise<import("./definitions/property").Property>;
    /**
     * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
     * Recommended usage: Instance.setApplicationProperty
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-setPropertyViaRestfulTable
     * @param options Request options.
     */
    setApplicationProperty<T = Instance.SetApplicationProperty.Response.OK>(options: Instance.SetApplicationProperty.Options): Promise<import("./definitions/property").Property>;
    /**
     * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
     * Recommended usage: Instance.getAdvancedSettings
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getAdvancedSettings
     * @param options Request options.
     */
    getAdvancedSettings<T = Instance.GetAdvancedSettings.Response.OK>(options?: Instance.GetAdvancedSettings.Options): Promise<Instance.GetAdvancedSettings.Response.OK>;
    /**
     * Returns the meta-data for an attachment, including the URI of the actual attached file.
     * Recommended usage: Issue.Attachment.getAttachment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-getAttachment
     * @param options Request options.
     */
    getIssueAttachment<T = Issue.Attachment.GetAttachment.Response.OK>(options: Issue.Attachment.GetAttachment.Options): Promise<import("./definitions/attachment").Attachment>;
    /**
     * Remove an attachment from an issue.
     * Recommended usage: Issue.Attachment.removeAttachment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-removeAttachment
     * @param options Request options.
     */
    removeIssueAttachment<T = Issue.Attachment.RemoveAttachment.Response.OK>(options: Issue.Attachment.RemoveAttachment.Options): Promise<undefined>;
    /**
     * Returns the meta information for an attachments, specifically if they are enabled and the maximum upload size allowed.
     * Recommended usage: Issue.Attachment.Metadata.getMetadata
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-getAttachmentMeta
     * @param options Request options.
     */
    getIssueAttachmentMetadata<T = Issue.Attachment.Metadata.GetMetadata.Response.OK>(options?: Issue.Attachment.Metadata.GetMetadata.Options): Promise<Issue.Attachment.Metadata.GetMetadata.Response.OK>;
    /**
     * Create a component via POST.
     * Recommended usage: Project.Component.createComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-createComponent
     * @param options Request options.
     */
    createProjectComponent<T = Project.Component.CreateComponent.Response.OK>(options: Project.Component.CreateComponent.Options): Promise<import("./definitions/component").Component>;
    /**
     * Returns a project component.
     * Recommended usage: Project.Component.getComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponent
     * @param options Request options.
     */
    getProjectComponent<T = Project.Component.GetComponent.Response.OK>(options: Project.Component.GetComponent.Options): Promise<import("./definitions/component").Component>;
    /**
     * Modify a component via PUT. If leadUserName is an empty string ("") the component lead will be removed.
     * Recommended usage: Project.Component.updateComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-updateComponent
     * @param options Request options.
     */
    updateProjectComponent<T = Project.Component.UpdateComponent.Response.OK>(options: Project.Component.UpdateComponent.Options): Promise<import("./definitions/component").Component>;
    /**
     * Delete a project component.
     * Recommended usage: Project.Component.deleteComponent
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-delete
     * @param options Request options.
     */
    deleteProjectComponent<T = Project.Component.DeleteComponent.Response.OK>(options: Project.Component.DeleteComponent.Options): Promise<undefined>;
    /**
     * Returns counts of issues related to this component.
     * Recommended usage: Project.Component.getRelatedIssues
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponentRelatedIssues
     * @param options Request options.
     */
    getProjectComponentRelatedIssues<T = Project.Component.GetRelatedIssues.Response.OK>(options: Project.Component.GetRelatedIssues.Options): Promise<Project.Component.GetRelatedIssues.Response.OK>;
    /**
     * Returns a list of all issue types visible to the user.
     * Recommended usage: Issue.Type.getTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueAllTypes
     * @param options Request options.
     */
    getIssueTypes<T = Issue.Type.GetTypes.Response.OK>(options?: Issue.Type.GetTypes.Options): Promise<Issue.Type.GetTypes.Response.OK>;
    /**
     * Returns a full representation of the issue type that has the given id.
     * Recommended usage: Issue.Type.getType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueType
     * @param options Request options.
     */
    getIssueType<T = Issue.Type.GetType.Response.OK>(options: Issue.Type.GetType.Options): Promise<import("./definitions/issue_type").IssueType>;
    /**
     * Returns currently logged in user.
     * Recommended usage: Myself.getCurrentUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/myself-getUser
     * @param options Request options.
     */
    getCurrentUser<T = Myself.GetCurrentUser.Response.OK>(options?: Myself.GetCurrentUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Returns a list of all issue priorities.
     * Recommended usage: Issue.Priority.getPriorities
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/priority-getPriorities
     * @param options Request options.
     */
    getIssuePriorities<T = Issue.Priority.GetPriorities.Response.OK>(options?: Issue.Priority.GetPriorities.Options): Promise<Issue.Priority.GetPriorities.Response.OK>;
    /**
     * Returns an issue priority.
     * Recommended usage: Issue.Priority.getPriority
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/priority-getPriority
     * @param options Request options.
     */
    getIssuePriority<T = Issue.Priority.GetPriority.Response.OK>(options: Issue.Priority.GetPriority.Options): Promise<import("./definitions/priority").Priority>;
    /**
     * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
     * Recommended usage: Project.getProjects
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllProjects
     * @param options Request options.
     */
    getProjects<T = Project.GetProjects.Response.OK>(options?: Project.GetProjects.Options): Promise<Project.GetProjects.Response.OK>;
    /**
     * Creates a new project.
     * Recommended usage: Project.createProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-createProject
     * @param options Request options.
     */
    createProject<T = Project.CreateProject.Response.OK>(options: Project.CreateProject.Options): Promise<Project.CreateProject.Response.OK>;
    /**
     * Contains a full representation of a project in JSON format.
     * Recommended usage: Project.getProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProject
     * @param options Request options.
     */
    getProject<T = Project.GetProject.Response.OK>(options: Project.GetProject.Options): Promise<import("./definitions/project").Project>;
    /**
     * Updates a project. Only non null values sent in JSON will be updated in the project.
     * Recommended usage: Project.updateProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProject
     * @param options Request options.
     */
    updateProject<T = Project.UpdateProject.Response.OK>(options: Project.UpdateProject.Options): Promise<import("./definitions/project").Project>;
    /**
     * Deletes a project.
     * Recommended usage: Project.deleteProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-deleteProject
     * @param options Request options.
     */
    deleteProject<T = Project.DeleteProject.Response.OK>(options: Project.DeleteProject.Options): Promise<undefined>;
    /**
     * Archives a project.
     * Recommended usage: Project.archiveProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-archiveProject
     * @param options Request options.
     */
    archiveProject<T = Project.ArchiveProject.Response.OK>(options: Project.ArchiveProject.Options): Promise<undefined>;
    /**
     * Contains a full representation of a the specified project's components.
     * Recommended usage: Project.getComponents
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectComponents
     * @param options Request options.
     */
    getProjectComponents<T = Project.GetComponents.Response.OK>(options: Project.GetComponents.Options): Promise<Project.GetComponents.Response.OK>;
    /**
     * Restore an archived project. In case of success restored project should be re-indexed.
     * Recommended usage: Project.restoreProject
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-restoreProject
     * @param options Request options.
     */
    restoreProject<T = Project.RestoreProject.Response.OK>(options: Project.RestoreProject.Options): Promise<undefined>;
    /**
     * Get all issue types with valid status values for a project.
     * Recommended usage: Project.getStatuses
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllStatuses
     * @param options Request options.
     */
    getProjectStatuses<T = Project.GetStatuses.Response.OK>(options: Project.GetStatuses.Options): Promise<Project.GetStatuses.Response.OK>;
    /**
     * Updates the type of a project.
     * Recommended usage: Project.updateProjectType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProjectType
     * @param options Request options.
     */
    updateProjectType<T = Project.UpdateProjectType.Response.OK>(options: Project.UpdateProjectType.Options): Promise<import("./definitions/project").Project>;
    /**
     * Returns all versions for the specified project. Results are paginated.
     * Recommended usage: Project.getVersionsPaginated
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersionsPaginated
     * @param options Request options.
     */
    getProjectVersionsPaginated<T = Project.GetVersionsPaginated.Response.OK>(options: Project.GetVersionsPaginated.Options): Promise<Project.GetVersionsPaginated.Response.OK>;
    /**
     * Contains a full representation of a the specified project's versions.
     * Recommended usage: Project.getVersions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersions
     * @param options Request options.
     */
    getProjectVersions<T = Project.GetVersions.Response.OK>(options: Project.GetVersions.Options): Promise<Project.GetVersions.Response.OK>;
    /**
     * Returns all roles in the given project Id or key, with links to full details on each role.
     * Recommended usage: Project.Role.getRoles
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRoles
     * @param options Request options.
     */
    getProjectRoles<T = Project.Role.GetRoles.Response.OK>(options: Project.Role.GetRoles.Options): Promise<Record<string, string>>;
    /**
     * Returns the details for a given project role in a project.
     * Recommended usage: Project.Role.getRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRole
     * @param options Request options.
     */
    getProjectRole<T = Project.Role.GetRole.Response.OK>(options: Project.Role.GetRole.Options): Promise<import("./definitions/project_role").ProjectRole>;
    /**
     * Updates a project role to include the specified actors (users or groups).
     * Recommended usage: Project.Role.Actor.setActors
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-setActors
     * @param options Request options.
     */
    setProjectRoleActors<T = Project.Role.Actor.SetActors.Response.OK>(options: Project.Role.Actor.SetActors.Options): Promise<import("./definitions/project_role").ProjectRole>;
    /**
     * Adds an actor (user or group) to a project role.
     * Recommended usage: Project.Role.Actor.addUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-addActorUsers
     * @param options Request options.
     */
    addProjectRoleActorUsers<T = Project.Role.Actor.AddUsers.Response.OK>(options: Project.Role.Actor.AddUsers.Options): Promise<import("./definitions/project_role").ProjectRole>;
    /**
     * Deletes actors (users or groups) from a project role.
     * Delete a user from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?user={username}
     * Delete a group from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?group={groupname}
     * Recommended usage: Project.Role.Actor.deleteActor
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-deleteActor
     * @param options Request options.
     */
    deleteProjectRoleActor<T = Project.Role.Actor.DeleteActor.Response.OK>(options: Project.Role.Actor.DeleteActor.Options): Promise<undefined>;
    /**
     * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
     * Recommended usage: Project.Type.getTypes
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAllProjectTypes
     * @param options Request options.
     */
    getProjectTypes<T = Project.Type.GetTypes.Response.OK>(options?: Project.Type.GetTypes.Options): Promise<Project.Type.GetTypes.Response.OK>;
    /**
     * Returns the project type with the given key.
     * Recommended usage: Project.Type.getType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getProjectTypeByKey
     * @param options Request options.
     */
    getProjectType<T = Project.Type.GetType.Response.OK>(options: Project.Type.GetType.Options): Promise<import("./definitions/project_type").ProjectType>;
    /**
     * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
     * Recommended usage: Project.Type.getAccessibleType
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAccessibleProjectTypeByKey
     * @param options Request options.
     */
    getAccessibleProjectType<T = Project.Type.GetAccessibleType.Response.OK>(options: Project.Type.GetAccessibleType.Options): Promise<import("./definitions/project_type").ProjectType>;
    /**
     * Validates a project key.
     * Recommended usage: Project.Validation.validateProjectKey
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/projectvalidate-getProject
     * @param options Request options.
     */
    validateProjectKey<T = Project.Validation.ValidateProjectKey.Response.OK>(options: Project.Validation.ValidateProjectKey.Options): Promise<Project.Validation.ValidateProjectKey.Response.OK>;
    /**
     * Returns a list of all resolutions.
     * Recommended usage: Issue.Resolution.getResolutions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/resolution-getResolutions
     * @param options Request options.
     */
    getIssueResolutions<T = Issue.Resolution.GetResolutions.Response.OK>(options?: Issue.Resolution.GetResolutions.Options): Promise<Issue.Resolution.GetResolutions.Response.OK>;
    /**
     * Returns a resolution.
     * Recommended usage: Issue.Resolution.getResolution
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/resolution-getResolution
     * @param options Request options.
     */
    getIssueResolution<T = Issue.Resolution.GetResolution.Response.OK>(options: Issue.Resolution.GetResolution.Options): Promise<import("./definitions/resolution").Resolution>;
    /**
     * Performs a search using JQL.
     * Recommended usage: Issue.Search.searchByJql
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/search-searchUsingSearchRequest
     * @param options Request options.
     */
    searchIssuesByJql<T = Issue.Search.SearchByJql.Response.OK>(options: Issue.Search.SearchByJql.Options): Promise<Issue.Search.SearchByJql.Response.OK>;
    /**
     * Returns general information about the current JIRA server.
     * Recommended usage: Instance.getInfo
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/serverInfo-getServerInfo
     * @param options Request options.
     */
    getInstanceInfo<T = Instance.GetInfo.Response.OK>(options?: Instance.GetInfo.Options): Promise<import("./definitions/instance").GetInfoResponse>;
    /**
     * Returns a list of all statuses.
     * Recommended usage: Workflow.Status.getStatuses
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatuses
     * @param options Request options.
     */
    getWorkflowStatuses<T = Workflow.Status.GetStatuses.Response.OK>(options?: Workflow.Status.GetStatuses.Options): Promise<Workflow.Status.GetStatuses.Response.OK>;
    /**
     * Returns a full representation of the Status having the given id or name.
     * Recommended usage: Workflow.Status.getStatus
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatus
     * @param options Request options.
     */
    getWorkflowStatus<T = Workflow.Status.GetStatus.Response.OK>(options: Workflow.Status.GetStatus.Options): Promise<import("./definitions/status").Status>;
    /**
     * Returns a list of all status categories.
     * Recommended usage: Workflow.Status.Category.getCategories
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategories
     * @param options Request options.
     */
    getWorkflowStatusCategories<T = Workflow.Status.Category.GetCategories.Response.OK>(options?: Workflow.Status.Category.GetCategories.Options): Promise<Workflow.Status.Category.GetCategories.Response.OK>;
    /**
     * Returns a full representation of the StatusCategory having the given id or key.
     * Recommended usage: Workflow.Status.Category.getCategory
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategory
     * @param options Request options.
     */
    getWorkflowStatusCategory<T = Workflow.Status.Category.GetCategory.Response.OK>(options: Workflow.Status.Category.GetCategory.Options): Promise<import("./definitions/status_category").StatusCategory>;
    /**
     * Returns a user.
     * Recommended usage: User.getUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-getUser
     * @param options Request options.
     */
    getUser<T = User.GetUser.Response.OK>(options: User.GetUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
     * Recommended usage: User.updateUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-updateUser
     * @param options Request options.
     */
    updateUser<T = User.UpdateUser.Response.OK>(options: User.UpdateUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
     * Recommended usage: User.createUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-createUser
     * @param options Request options.
     */
    createUser<T = User.CreateUser.Response.OK>(options: User.CreateUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Removes user and its references (like project roles associations, watches, history).
     * Recommended usage: User.removeUser
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUser
     * @param options Request options.
     */
    removeUser<T = User.RemoveUser.Response.OK>(options: User.RemoveUser.Options): Promise<undefined>;
    /**
     * Add user to given application. Admin permission will be required to perform this operation.
     * Recommended usage: User.addUserToApplication
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-addUserToApplication
     * @param options Request options.
     */
    addUserToApplication<T = User.AddUserToApplication.Response.OK>(options: User.AddUserToApplication.Options): Promise<undefined>;
    /**
     * Remove user from given application. Admin permission will be required to perform this operation.
     * Recommended usage: User.removeUserFromApplication
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUserFromApplication
     * @param options Request options.
     */
    removeUserFromApplication<T = User.RemoveUserFromApplication.Response.OK>(options: User.RemoveUserFromApplication.Options): Promise<undefined>;
    /**
     * Modify user password.
     * Recommended usage: User.changeUserPassword
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-changeUserPassword
     * @param options Request options.
     */
    changeUserPassword<T = User.ChangeUserPassword.Response.OK>(options: User.ChangeUserPassword.Options): Promise<undefined>;
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously. Please note that this resource should be called with an issue key when a list of assignable users is retrieved for editing. For create only a project key should be supplied. The list of assignable users may be incorrect if it's called with the project key for editing.
     * Recommended usage: User.Search.findAssignableUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findAssignableUsers
     * @param options Request options.
     */
    findAssignableUsers<T = User.Search.FindAssignableUsers.Response.OK>(options: User.Search.FindAssignableUsers.Options): Promise<User.Search.FindAssignableUsers.Response.OK>;
    /**
     * Returns a list of active users that match the search string and have all specified permissions for the project or issue.
     * This resource can be accessed by users with ADMINISTER_PROJECT permission for the project or global ADMIN or SYSADMIN rights.
     * Recommended usage: User.Search.findUsersWithAllPermissions
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithAllPermissions
     * @param options Request options.
     */
    findUsersWithAllPermissions<T = User.Search.FindUsersWithAllPermissions.Response.OK>(options: User.Search.FindUsersWithAllPermissions.Options): Promise<User.Search.FindUsersWithAllPermissions.Response.OK>;
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously.
     * Recommended usage: User.Search.findUsers
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsers
     * @param options Request options.
     */
    findUsers<T = User.Search.FindUsers.Response.OK>(options: User.Search.FindUsers.Options): Promise<User.Search.FindUsers.Response.OK>;
    /**
     * Returns a list of active users that match the search string. This resource cannot be accessed anonymously and requires the Browse Users global permission. Given an issue key this resource will provide a list of users that match the search string and have the browse issue permission for the issue provided.
     * Recommended usage: User.Search.findUsersWithBrowsePermission
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithBrowsePermission
     * @param options Request options.
     */
    findUsersWithBrowsePermission<T = User.Search.FindUsersWithBrowsePermission.Response.OK>(options: User.Search.FindUsersWithBrowsePermission.Options): Promise<User.Search.FindUsersWithBrowsePermission.Response.OK>;
    /**
     * Create a version via POST.
     * Recommended usage: Project.Version.createVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-createVersion
     * @param options Request options.
     */
    createProjectVersion<T = Project.Version.CreateVersion.Response.OK>(options: Project.Version.CreateVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Modify a version's sequence within a project.
     * Recommended usage: Project.Version.moveVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-moveVersion
     * @param options Request options.
     */
    moveProjectVersion<T = Project.Version.MoveVersion.Response.OK>(options: Project.Version.MoveVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Returns a project version.
     * Recommended usage: Project.Version.getVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersion
     * @param options Request options.
     */
    getProjectVersion<T = Project.Version.GetVersion.Response.OK>(options: Project.Version.GetVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Modify a version via PUT. Any fields present in the PUT will override existing values. As a convenience, if a field is not present, it is silently ignored.
     * Recommended usage: Project.Version.updateVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-updateVersion
     * @param options Request options.
     */
    updateProjectVersion<T = Project.Version.UpdateVersion.Response.OK>(options: Project.Version.UpdateVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Delete a project version.
     * Recommended usage: Project.Version.deleteVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
     * @param options Request options.
     */
    deleteProjectVersion<T = Project.Version.DeleteVersion.Response.OK>(options: Project.Version.DeleteVersion.Options): Promise<undefined>;
    /**
     * Merge versions.
     * Recommended usage: Project.Version.mergeVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-merge
     * @param options Request options.
     */
    mergeProjectVersion<T = Project.Version.MergeVersion.Response.OK>(options: Project.Version.MergeVersion.Options): Promise<undefined>;
    /**
     * Delete a project version.
     * Recommended usage: Project.Version.removeAndReplaceVersion
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
     * @param options Request options.
     */
    removeAndReplaceProjectVersion<T = Project.Version.RemoveAndReplaceVersion.Response.OK>(options: Project.Version.RemoveAndReplaceVersion.Options): Promise<undefined>;
    /**
     * Returns a bean containing the number of fixed in and affected issues for the given version.
     * Recommended usage: Project.Version.Count.getVersionRelatedIssueCount
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionRelatedIssues
     * @param options Request options.
     */
    getProjectVersionRelatedIssueCount<T = Project.Version.Count.GetVersionRelatedIssueCount.Response.OK>(options: Project.Version.Count.GetVersionRelatedIssueCount.Options): Promise<Project.Version.Count.GetVersionRelatedIssueCount.Response.OK>;
    /**
     * Returns the number of unresolved issues for the given version
     * Recommended usage: Project.Version.Count.getVersionUnresolvedIssueCount
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionUnresolvedIssues
     * @param options Request options.
     */
    getProjectVersionUnresolvedIssueCount<T = Project.Version.Count.GetVersionUnresolvedIssueCount.Response.OK>(options: Project.Version.Count.GetVersionUnresolvedIssueCount.Options): Promise<Project.Version.Count.GetVersionUnresolvedIssueCount.Response.OK>;
    /**
     * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
     * Recommended usage: Issue.Worklog.getDeletedWorklogIds
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsDeletedSince
     * @param options Request options.
     */
    getDeletedIssueWorklogIds<T = Issue.Worklog.GetDeletedWorklogIds.Response.OK>(options?: Issue.Worklog.GetDeletedWorklogIds.Options): Promise<Issue.Worklog.GetDeletedWorklogIds.Response.OK>;
    /**
     * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
     * Recommended usage: Issue.Worklog.getWorklogsForIds
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getWorklogsForIds
     * @param options Request options.
     */
    getIssueWorklogsForIds<T = Issue.Worklog.GetWorklogsForIds.Response.OK>(options: Issue.Worklog.GetWorklogsForIds.Options): Promise<Issue.Worklog.GetWorklogsForIds.Response.OK>;
    /**
     * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
     * Recommended usage: Issue.Worklog.getUpdatedWorklogIds
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsModifiedSince
     * @param options Request options.
     */
    getUpdatedIssueWorklogIds<T = Issue.Worklog.GetUpdatedWorklogIds.Response.OK>(options?: Issue.Worklog.GetUpdatedWorklogIds.Options): Promise<Issue.Worklog.GetUpdatedWorklogIds.Response.OK>;
    /**
    * Get all the ProjectRoles available in JIRA. Currently this list is global.
    * Recommended usage: Role.Project.getRoles
    * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/role-getProjectRoles
    * @param options Request options.
    */
    getGlobalProjectRoles<T = Role.Project.GetRoles.Response.OK>(options?: Role.Project.GetRoles.Options): Promise<Role.Project.GetRoles.Response.OK>;
    /**
     * Get a specific ProjectRole available in JIRA.
     * Recommended usage: Role.Project.getRole
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/role-getProjectRolesById
     * @param options Request options.
     */
    getGlobalProjectRole<T = Role.Project.GetRole.Response.OK>(options: Role.Project.GetRole.Options): Promise<import("./definitions/project_role").ProjectRole>;
    /**
     * Add one or more attachments to an issue.
     * Recommended usage: Issue.Attachment.addAttachment
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/attachments-addAttachment
     * @param options Request options.
     */
    addIssueAttachment<T = Issue.Attachment.AddAttachment.Response.OK>(options: Issue.Attachment.AddAttachment.Options): Promise<Issue.Attachment.AddAttachment.Response.OK>;
}
declare class BuildersGroup {
    private issueHelper;
    constructor(issueHelper: IssueHelper);
    get ErrorStrategy(): ErrorStrategyBuilder;
    get IssueBuilder(): import("./builder/issue").IssueBuilder;
}
declare class IssueGroup extends BaseGroup {
    private issueHelper;
    Comment: CommentGroup;
    Metadata: MetadataGroup;
    Link: LinkGroup;
    Vote: VoteGroup;
    Watcher: WatcherGroup;
    Worklog: WorklogGroup;
    Transition: TransitionGroup;
    SubTask: SubTaskGroup;
    Field: FieldGroup;
    Attachment: AttachmentGroup;
    Type: TypeGroup;
    Priority: PriorityGroup;
    Resolution: ResolutionGroup;
    Search: SearchGroup;
    constructor(connection: string, options: ConnectionOptions, issueHelper: IssueHelper);
    /**
     * Creates an issue or a sub-task from a JSON representation.
     * The fields that can be set on create, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/createmeta resource. If a field is not configured to appear on the create screen, then it will not be in the createmeta, and a field validation error will occur if it is submitted.
     * Creating a sub-task is similar to creating a regular issue, with two important differences:
     * the issueType field must correspond to a sub-task issue type (you can use /issue/createmeta to discover sub-task issue types), and you must provide a parent field in the issue create request containing the id or key of the parent issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createIssue
     * @param options Request options.
     */
    createIssue<T = Issue.CreateIssue.Response.OK>(options: Issue.CreateIssue.Options): Promise<Issue.CreateIssue.Response.OK>;
    /**
     * Delete an issue. If the issue has subtasks you must set the parameter deleteSubtasks=true to delete the issue. You cannot delete an issue without its subtasks also being deleted.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteIssue
     * @param options Request options.
     */
    deleteIssue<T = Issue.DeleteIssue.Response.OK>(options: Issue.DeleteIssue.Options): Promise<undefined>;
    /**
     * Returns a full representation of the issue for the given issue key.
     * JIRA will attempt to identify the issue by the issueIdOrKey path parameter. This can be an issue id, or an issue key. If the issue cannot be found via an exact match, JIRA will also look for the issue in a case-insensitive way, or by looking to see if the issue was moved. In either of these cases, the request will proceed as normal (a 302 or other redirect will not be returned). The issue key contained in the response will indicate the current value of issue's key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssue
     * @param options Request options.
     */
    getIssue<T = ManagedIssue.Read.Response>(options: Issue.GetIssue.Options): Promise<ManagedIssue.Read.Response | T>;
    /**
     * Edits an issue from a JSON representation.
     * The issue can either be updated by setting explicit the field value(s) or by using an operation to change the field value.
     * The fields that can be updated, in either the fields parameter or the update parameter, can be determined using the /rest/api/2/issue/{issueIdOrKey}/editmeta resource.
     * If a field is not configured to appear on the edit screen, then it will not be in the editmeta, and a field validation error will occur if it is submitted.
     * Specifying a "field_id": field_value in the "fields" is a shorthand for a "set" operation in the "update" section.
     * Field should appear either in "fields" or "update", not in both.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-editIssue
     * @param options Request options.
     */
    editIssue<T = Issue.EditIssue.Response.OK>(options: Issue.EditIssue.Options): Promise<undefined>;
    /**
     * Assigns an issue to a user. You can use this resource to assign issues when the user submitting the request has the assign permission but not the edit issue permission. If the name is "-1" automatic assignee is used. A null name will remove the assignee.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-assign
     * @param options Request options.
     */
    assignIssue<T = Issue.AssignIssue.Response.OK>(options: Issue.AssignIssue.Options): Promise<undefined>;
    /**
     * Sends a notification (email) to the list or recipients defined in the request.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-notify
     * @param options Request options.
     */
    sendNotification<T = Issue.SendNotification.Response.OK>(options: Issue.SendNotification.Options): Promise<undefined>;
}
declare class CommentGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all comments for an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComments
     * @param options Request options.
     */
    getComments<T = Issue.Comment.GetComments.Response.OK>(options: Issue.Comment.GetComments.Options): Promise<Issue.Comment.GetComments.Response.OK>;
    /**
     * Adds a new comment to an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addComment
     * @param options Request options.
     */
    addComment<T = Issue.Comment.AddComment.Response.OK>(options: Issue.Comment.AddComment.Options): Promise<import("./definitions/comment").Comment>;
    /**
     * Returns a single comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComment
     * @param options Request options.
     */
    getComment<T = Issue.Comment.GetComment.Response.OK>(options: Issue.Comment.GetComment.Options): Promise<import("./definitions/comment").Comment>;
    /**
     * Updates an existing comment using its JSON representation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateComment
     * @param options Request options.
     */
    updateComment<T = Issue.Comment.UpdateComment.Response.OK>(options: Issue.Comment.UpdateComment.Options): Promise<import("./definitions/comment").Comment>;
    /**
     * Deletes an existing comment.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteComment
     * @param options Request options.
     */
    deleteComment<T = Issue.Comment.DeleteComment.Response.OK>(options: Issue.Comment.DeleteComment.Options): Promise<undefined>;
}
declare class MetadataGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns the meta data for editing an issue. The fields in the editmeta correspond to the fields in the edit screen for the issue. Fields not in the screen will not be in the editmeta.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getEditIssueMeta
     * @param options Request options.
     */
    getEditMetadata<T = Issue.Metadata.GetEditMetadata.Response.OK>(options: Issue.Metadata.GetEditMetadata.Options): Promise<Issue.Metadata.GetEditMetadata.Response.OK>;
    /**
     * Returns the meta data for creating issues. This includes the available projects, issue types and fields, including field types and whether or not those fields are required. Projects will not be returned if the user does not have permission to create issues in that project.
     * The fields in the createmeta correspond to the fields in the create screen for the project/issuetype. Fields not in the screen will not be in the createmeta.
     * Fields will only be returned if expand=projects.issuetypes.fields.
     * The results can be filtered by project and/or issue type, given by the query params.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getCreateIssueMeta
     * @param options Request options.
     */
    getCreateMetadata<T = Issue.Metadata.GetCreateMetadata.Response.OK>(options?: Issue.Metadata.GetCreateMetadata.Options): Promise<Issue.Metadata.GetCreateMetadata.Response.OK>;
}
declare class LinkGroup extends BaseGroup {
    Type: LinkTypeGroup;
    Remote: RemoteGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Creates an issue link between two issues. The user requires the link issue permission for the issue which will be linked to another issue. The specified link type in the request is used to create the link and will create a link from the first issue to the second issue using the outward description. It also create a link from the second issue to the first issue using the inward description of the issue link type. It will add the supplied comment to the first issue. The comment can have a restriction who can view it. If group is specified, only users of this group can view this comment, if roleLevel is specified only users who have the specified role can view this comment. The user who creates the issue link needs to belong to the specified group or have the specified role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-linkIssues
     * @param options Request options.
     */
    createLink<T = Issue.Link.CreateLink.Response.OK>(options: Issue.Link.CreateLink.Options): Promise<undefined>;
    /**
     * Returns an issue link with the specified id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-getIssueLink
     * @param options Request options.
     */
    getLink<T = Issue.Link.GetLink.Response.OK>(options: Issue.Link.GetLink.Options): Promise<Issue.Link.GetLink.Response.OK>;
    /**
     * Deletes an issue link with the specified id. To be able to delete an issue link you must be able to view both issues and must have the link issue permission for at least one of the issues.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-deleteIssueLink
     * @param options Request options.
     */
    deleteLink<T = Issue.Link.DeleteLink.Response.OK>(options: Issue.Link.DeleteLink.Options): Promise<undefined>;
}
declare class RemoteGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * A REST sub-resource representing the remote issue links on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinks
     * @param options Request options.
     */
    getLinks<T = Issue.Link.Remote.GetLinks.Response.OK>(options: Issue.Link.Remote.GetLinks.Options): Promise<Issue.Link.Remote.GetLinks.Response.OK>;
    /**
     * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createOrUpdateRemoteIssueLink
     * @param options Request options.
     */
    createOrUpdateLink<T = Issue.Link.Remote.CreateOrUpdateLink.Response.OK>(options: Issue.Link.Remote.CreateOrUpdateLink.Options): Promise<Issue.Link.Remote.CreateOrUpdateLink.Response.OK>;
    /**
     * Delete the remote issue link with the given global id on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkByGlobalId
     * @param options Request options.
     */
    deleteLinkByGlobalId<T = Issue.Link.Remote.DeleteLinkByGlobalId.Response.OK>(options: Issue.Link.Remote.DeleteLinkByGlobalId.Options): Promise<undefined>;
    /**
     * Get the remote issue link with the given id on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinkById
     * @param options Request options.
     */
    getLink<T = Issue.Link.Remote.GetLink.Response.OK>(options: Issue.Link.Remote.GetLink.Options): Promise<Issue.Link.Remote.GetLink.Response.OK>;
    /**
     * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateRemoteIssueLink
     * @param options Request options.
     */
    updateLink<T = Issue.Link.Remote.UpdateLink.Response.OK>(options: Issue.Link.Remote.UpdateLink.Options): Promise<undefined>;
    /**
     * Delete the remote issue link with the given id on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkById
     * @param options Request options.
     */
    deleteLink<T = Issue.Link.Remote.DeleteLink.Response.OK>(options: Issue.Link.Remote.DeleteLink.Options): Promise<undefined>;
}
declare class VoteGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Remove your vote from an issue. (i.e. "unvote").
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeVote
     * @param options Request options.
     */
    removeVote<T = Issue.Vote.RemoveVote.Response.OK>(options: Issue.Vote.RemoveVote.Options): Promise<undefined>;
    /**
     * Cast your vote in favour of an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addVote
     * @param options Request options.
     */
    addVote<T = Issue.Vote.AddVote.Response.OK>(options: Issue.Vote.AddVote.Options): Promise<undefined>;
    /**
     * A REST sub-resource representing the voters on the issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getVotes
     * @param options Request options.
     */
    getVotes<T = Issue.Vote.GetVotes.Response.OK>(options: Issue.Vote.GetVotes.Options): Promise<Issue.Vote.GetVotes.Response.OK>;
}
declare class WatcherGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns the list of watchers for the issue with the given key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWatchers
     * @param options Request options.
     */
    getWatchers<T = Issue.Watcher.GetWatchers.Response.OK>(options: Issue.Watcher.GetWatchers.Options): Promise<Issue.Watcher.GetWatchers.Response.OK>;
    /**
     * Adds a user to an issue's watcher list.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWatcher
     * @param options Request options.
     */
    addWatcher<T = Issue.Watcher.AddWatcher.Response.OK>(options: Issue.Watcher.AddWatcher.Options): Promise<undefined>;
    /**
     * Removes a user from an issue's watcher list.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeWatcher
     * @param options Request options.
     */
    removeWatcher<T = Issue.Watcher.RemoveWatcher.Response.OK>(options: Issue.Watcher.RemoveWatcher.Options): Promise<undefined>;
}
declare class WorklogGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWorklog
     * @param options Request options.
     */
    getWorklogs<T = Issue.Worklog.GetWorklogs.Response.OK>(options: Issue.Worklog.GetWorklogs.Options): Promise<Issue.Worklog.GetWorklogs.Response.OK>;
    /**
     * Adds a new worklog entry to an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWorklog
     * @param options Request options.
     */
    addWorklog<T = Issue.Worklog.AddWorklog.Response.OK>(options: Issue.Worklog.AddWorklog.Options): Promise<import("./definitions/worklog").Worklog>;
    /**
     * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getWorklog
     * @param options Request options.
     */
    getWorklog<T = Issue.Worklog.GetWorklog.Response.OK>(options: Issue.Worklog.GetWorklog.Options): Promise<import("./definitions/worklog").Worklog>;
    /**
     * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateWorklog
     * @param options Request options.
     */
    updateWorklog<T = Issue.Worklog.UpdateWorklog.Response.OK>(options: Issue.Worklog.UpdateWorklog.Options): Promise<import("./definitions/worklog").Worklog>;
    /**
     * Deletes an existing worklog entry.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteWorklog
     * @param options Request options.
     */
    deleteWorklog<T = Issue.Worklog.DeleteWorklog.Response.OK>(options: Issue.Worklog.DeleteWorklog.Options): Promise<undefined>;
    /**
     * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsDeletedSince
     * @param options Request options.
     */
    getDeletedWorklogIds<T = Issue.Worklog.GetDeletedWorklogIds.Response.OK>(options?: Issue.Worklog.GetDeletedWorklogIds.Options): Promise<Issue.Worklog.GetDeletedWorklogIds.Response.OK>;
    /**
     * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getWorklogsForIds
     * @param options Request options.
     */
    getWorklogsForIds<T = Issue.Worklog.GetWorklogsForIds.Response.OK>(options: Issue.Worklog.GetWorklogsForIds.Options): Promise<Issue.Worklog.GetWorklogsForIds.Response.OK>;
    /**
     * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsModifiedSince
     * @param options Request options.
     */
    getUpdatedWorklogIds<T = Issue.Worklog.GetUpdatedWorklogIds.Response.OK>(options?: Issue.Worklog.GetUpdatedWorklogIds.Options): Promise<Issue.Worklog.GetUpdatedWorklogIds.Response.OK>;
}
declare class TransitionGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Get a list of the transitions possible for this issue by the current user, along with fields that are required and their types.
     * Fields will only be returned if expand=transitions.fields.
     * The fields in the metadata correspond to the fields in the transition screen for that transition. Fields not in the screen will not be in the metadata.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getTransitions
     * @param options Request options.
     */
    getTransitions<T = Issue.Transition.GetTransitions.Response.OK>(options: Issue.Transition.GetTransitions.Options): Promise<Issue.Transition.GetTransitions.Response.OK>;
    /**
     * Perform a transition on an issue. When performing the transition you can update or set other issue fields.
     * The fields that can be set on transtion, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/{issueIdOrKey}/transitions?expand=transitions.fields resource. If a field is not configured to appear on the transition screen, then it will not be in the transition metadata, and a field validation error will occur if it is submitted. The updateHistory param adds the issues retrieved by this method to the current user's issue history, if set to true (by default, the issue history does not include issues retrieved via the REST API). You can view the issue history in the JIRA application, via the Issues dropdown or by using the lastViewed JQL field in an issue search.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-doTransition
     * @param options Request options.
     */
    performTransition<T = Issue.Transition.PerformTransition.Response.OK>(options: Issue.Transition.PerformTransition.Options): Promise<undefined>;
}
declare class SubTaskGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns an issue's subtask list.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-getSubTasks
     * @param options Request options.
     */
    getSubTasks<T = Issue.SubTask.GetSubTasks.Response.OK>(options: Issue.SubTask.GetSubTasks.Options): Promise<Issue.SubTask.GetSubTasks.Response.OK>;
    /**
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-canMoveSubTask
     * @param options Request options.
     */
    canMoveSubTask<T = Issue.SubTask.CanMoveSubTask.Response.OK>(options: Issue.SubTask.CanMoveSubTask.Options): Promise<boolean>;
    /**
     * Reorders an issue's subtasks by moving the subtask at index "from" to index "to".
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-moveSubTasks
     * @param options Request options.
     */
    moveSubTasks<T = Issue.SubTask.MoveSubTasks.Response.OK>(options: Issue.SubTask.MoveSubTasks.Options): Promise<undefined>;
}
declare class LinkTypeGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkTypes
     * @param options Request options.
     */
    getTypes<T = Issue.Link.Type.GetTypes.Response.OK>(options?: Issue.Link.Type.GetTypes.Options): Promise<Issue.Link.Type.GetTypes.Response.OK>;
    /**
     * Returns for a given issue link type id all information about this issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkType
     * @param options Request options.
     */
    getType<T = Issue.Link.Type.GetType.Response.OK>(options: Issue.Link.Type.GetType.Options): Promise<import("./definitions/issue_link_type").IssueLinkType>;
    /**
     * Create a new issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-createIssueLinkType
     * @param options Request options.
     */
    createType<T = Issue.Link.Type.CreateType.Response.OK>(options: Issue.Link.Type.CreateType.Options): Promise<import("./definitions/issue_link_type").IssueLinkType>;
    /**
     * Delete the specified issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-deleteIssueLinkType
     * @param options Request options.
     */
    deleteType<T = Issue.Link.Type.DeleteType.Response.OK>(options: Issue.Link.Type.DeleteType.Options): Promise<undefined>;
    /**
     * Update the specified issue link type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-updateIssueLinkType
     * @param options Request options.
     */
    updateType<T = Issue.Link.Type.UpdateType.Response.OK>(options: Issue.Link.Type.UpdateType.Options): Promise<import("./definitions/issue_link_type").IssueLinkType>;
}
declare class AttachmentGroup extends BaseGroup {
    Metadata: AttachmentMetadataGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns the meta-data for an attachment, including the URI of the actual attached file.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-getAttachment
     * @param options Request options.
     */
    getAttachment<T = Issue.Attachment.GetAttachment.Response.OK>(options: Issue.Attachment.GetAttachment.Options): Promise<import("./definitions/attachment").Attachment>;
    /**
     * Remove an attachment from an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-removeAttachment
     * @param options Request options.
     */
    removeAttachment<T = Issue.Attachment.RemoveAttachment.Response.OK>(options: Issue.Attachment.RemoveAttachment.Options): Promise<undefined>;
    /**
     * Add one or more attachments to an issue.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/attachments-addAttachment
     * @param options Request options.
     */
    addAttachment<T = Issue.Attachment.AddAttachment.Response.OK>(options: Issue.Attachment.AddAttachment.Options): Promise<Issue.Attachment.AddAttachment.Response.OK>;
}
declare class AttachmentMetadataGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns the meta information for an attachments, specifically if they are enabled and the maximum upload size allowed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-getAttachmentMeta
     * @param options Request options.
     */
    getMetadata<T = Issue.Attachment.Metadata.GetMetadata.Response.OK>(options?: Issue.Attachment.Metadata.GetMetadata.Options): Promise<Issue.Attachment.Metadata.GetMetadata.Response.OK>;
}
declare class GroupGroup extends BaseGroup {
    User: GroupUserGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Creates a group by given group parameter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-createGroup
     * @param options Request options.
     */
    createGroup<T = Group.CreateGroup.Response.OK>(options: Group.CreateGroup.Options): Promise<import("./definitions/group").GroupResponse>;
    /**
     * Deletes a group by given group parameter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeGroup
     * @param options Request options.
     */
    removeGroup<T = Group.RemoveGroup.Response.OK>(options: Group.RemoveGroup.Options): Promise<undefined>;
}
declare class GroupUserGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * This resource returns a paginated list of users who are members of the specified group and its subgroups. Users in the page are ordered by user names. User of this resource is required to have sysadmin or admin permissions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-getUsersFromGroup
     * @param options Request options.
     */
    getUsers<T = Group.User.GetUsers.Response.OK>(options: Group.User.GetUsers.Options): Promise<import("./definitions/group").GetUsersResponse>;
    /**
     * Adds given user to a group.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-addUserToGroup
     * @param options Request options.
     */
    addUsers<T = Group.User.AddUsers.Response.OK>(options: Group.User.AddUsers.Options): Promise<import("./definitions/group").GroupResponse>;
    /**
     * Removes given user from a group.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeUserFromGroup
     * @param options Request options.
     */
    removeUsers<T = Group.User.RemoveUsers.Response.OK>(options: Group.User.RemoveUsers.Options): Promise<undefined>;
}
declare class FilterGroup extends BaseGroup {
    Column: FilterColumnGroup;
    Share: FilterShareGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a filter given an id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFilter
     * @param options Request options.
     */
    getFilter<T = Filter.GetFilter.Response.OK>(options: Filter.GetFilter.Options): Promise<import("./definitions/filter").Filter>;
    /**
     * Returns the favourite filters of the logged-in user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFavouriteFilters
     * @param options Request options.
     */
    getMyFavouriteFilters<T = Filter.GetMyFavouriteFilters.Response.OK>(options?: Filter.GetMyFavouriteFilters.Options): Promise<Filter.GetMyFavouriteFilters.Response.OK>;
    /**
     * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-createFilter
     * @param options Request options.
     */
    createFilter<T = Filter.CreateFilter.Response.OK>(options: Filter.CreateFilter.Options): Promise<import("./definitions/filter").Filter>;
    /**
     * Updates an existing filter, and returns its new value.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-editFilter
     * @param options Request options.
     */
    editFilter<T = Filter.EditFilter.Response.OK>(options: Filter.EditFilter.Options): Promise<import("./definitions/filter").Filter>;
    /**
     * Delete a filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-deleteFilter
     * @param options Request options.
     */
    deleteFilter<T = Filter.DeleteFilter.Response.OK>(options: Filter.DeleteFilter.Options): Promise<undefined>;
}
declare class FieldGroup extends BaseGroup {
    Custom: CustomGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all fields, both System and Custom.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/field-getFields
     * @param options Request options.
     */
    getFields<T = Issue.Field.GetFields.Response.OK>(options?: Issue.Field.GetFields.Options): Promise<Issue.Field.GetFields.Response.OK>;
}
declare class InstanceGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns an application property.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getProperty
     * @param options Request options.
     */
    getApplicationProperty<T = Instance.GetApplicationProperty.Response.OK>(options?: Instance.GetApplicationProperty.Options): Promise<import("./definitions/property").Property>;
    /**
     * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-setPropertyViaRestfulTable
     * @param options Request options.
     */
    setApplicationProperty<T = Instance.SetApplicationProperty.Response.OK>(options: Instance.SetApplicationProperty.Options): Promise<import("./definitions/property").Property>;
    /**
     * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getAdvancedSettings
     * @param options Request options.
     */
    getAdvancedSettings<T = Instance.GetAdvancedSettings.Response.OK>(options?: Instance.GetAdvancedSettings.Options): Promise<Instance.GetAdvancedSettings.Response.OK>;
    /**
     * Returns the information if the optional features in JIRA are enabled or disabled. If the time tracking is enabled, it also returns the detailed information about time tracking configuration.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/configuration-getConfiguration
     * @param options Request options.
     */
    getConfiguration<T = Instance.GetConfiguration.Response.OK>(options?: Instance.GetConfiguration.Options): Promise<import("./definitions/instance").GetConfigurationResponse>;
    /**
     * Returns general information about the current JIRA server.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/serverInfo-getServerInfo
     * @param options Request options.
     */
    getInfo<T = Instance.GetInfo.Response.OK>(options?: Instance.GetInfo.Options): Promise<import("./definitions/instance").GetInfoResponse>;
}
declare class ProjectGroup extends BaseGroup {
    Component: ComponentGroup;
    Role: ProjectRoleGroup;
    Type: ProjectTypeGroup;
    Validation: ProjectValidationGroup;
    Version: ProjectVersionGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllProjects
     * @param options Request options.
     */
    getProjects<T = Project.GetProjects.Response.OK>(options?: Project.GetProjects.Options): Promise<Project.GetProjects.Response.OK>;
    /**
     * Creates a new project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-createProject
     * @param options Request options.
     */
    createProject<T = Project.CreateProject.Response.OK>(options: Project.CreateProject.Options): Promise<Project.CreateProject.Response.OK>;
    /**
     * Contains a full representation of a project in JSON format.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProject
     * @param options Request options.
     */
    getProject<T = Project.GetProject.Response.OK>(options: Project.GetProject.Options): Promise<import("./definitions/project").Project>;
    /**
     * Updates a project. Only non null values sent in JSON will be updated in the project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProject
     * @param options Request options.
     */
    updateProject<T = Project.UpdateProject.Response.OK>(options: Project.UpdateProject.Options): Promise<import("./definitions/project").Project>;
    /**
     * Deletes a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-deleteProject
     * @param options Request options.
     */
    deleteProject<T = Project.DeleteProject.Response.OK>(options: Project.DeleteProject.Options): Promise<undefined>;
    /**
     * Archives a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-archiveProject
     * @param options Request options.
     */
    archiveProject<T = Project.ArchiveProject.Response.OK>(options: Project.ArchiveProject.Options): Promise<undefined>;
    /**
     * Contains a full representation of a the specified project's components.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectComponents
     * @param options Request options.
     */
    getComponents<T = Project.GetComponents.Response.OK>(options: Project.GetComponents.Options): Promise<Project.GetComponents.Response.OK>;
    /**
     * Restore an archived project. In case of success restored project should be re-indexed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-restoreProject
     * @param options Request options.
     */
    restoreProject<T = Project.RestoreProject.Response.OK>(options: Project.RestoreProject.Options): Promise<undefined>;
    /**
     * Get all issue types with valid status values for a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllStatuses
     * @param options Request options.
     */
    getStatuses<T = Project.GetStatuses.Response.OK>(options: Project.GetStatuses.Options): Promise<Project.GetStatuses.Response.OK>;
    /**
     * Updates the type of a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProjectType
     * @param options Request options.
     */
    updateProjectType<T = Project.UpdateProjectType.Response.OK>(options: Project.UpdateProjectType.Options): Promise<import("./definitions/project").Project>;
    /**
     * Returns all versions for the specified project. Results are paginated.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersionsPaginated
     * @param options Request options.
     */
    getVersionsPaginated<T = Project.GetVersionsPaginated.Response.OK>(options: Project.GetVersionsPaginated.Options): Promise<Project.GetVersionsPaginated.Response.OK>;
    /**
     * Contains a full representation of a the specified project's versions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersions
     * @param options Request options.
     */
    getVersions<T = Project.GetVersions.Response.OK>(options: Project.GetVersions.Options): Promise<Project.GetVersions.Response.OK>;
}
declare class ComponentGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Create a component via POST.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-createComponent
     * @param options Request options.
     */
    createComponent<T = Project.Component.CreateComponent.Response.OK>(options: Project.Component.CreateComponent.Options): Promise<import("./definitions/component").Component>;
    /**
     * Returns a project component.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponent
     * @param options Request options.
     */
    getComponent<T = Project.Component.GetComponent.Response.OK>(options: Project.Component.GetComponent.Options): Promise<import("./definitions/component").Component>;
    /**
     * Modify a component via PUT. If leadUserName is an empty string ("") the component lead will be removed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-updateComponent
     * @param options Request options.
     */
    updateComponent<T = Project.Component.UpdateComponent.Response.OK>(options: Project.Component.UpdateComponent.Options): Promise<import("./definitions/component").Component>;
    /**
     * Delete a project component.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-delete
     * @param options Request options.
     */
    deleteComponent<T = Project.Component.DeleteComponent.Response.OK>(options: Project.Component.DeleteComponent.Options): Promise<undefined>;
    /**
     * Returns counts of issues related to this component.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponentRelatedIssues
     * @param options Request options.
     */
    getRelatedIssues<T = Project.Component.GetRelatedIssues.Response.OK>(options: Project.Component.GetRelatedIssues.Options): Promise<Project.Component.GetRelatedIssues.Response.OK>;
}
declare class CustomGroup extends BaseGroup {
    Option: OptionGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/customFields-getCustomFields
     * @param options Request options.
     */
    getFields<T = Issue.Field.Custom.GetFields.Response.OK>(options?: Issue.Field.Custom.GetFields.Options): Promise<Issue.Field.Custom.GetFields.Response.OK>;
}
declare class OptionGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a full representation of the Custom Field Option that has the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/customFieldOption-getCustomFieldOption
     * @param options Request options.
     */
    getOption<T = Issue.Field.Custom.Option.GetOption.Response.OK>(options: Issue.Field.Custom.Option.GetOption.Options): Promise<Issue.Field.Custom.Option.GetOption.Response.OK>;
}
declare class TypeGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all issue types visible to the user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueAllTypes
     * @param options Request options.
     */
    getTypes<T = Issue.Type.GetTypes.Response.OK>(options?: Issue.Type.GetTypes.Options): Promise<Issue.Type.GetTypes.Response.OK>;
    /**
     * Returns a full representation of the issue type that has the given id.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueType
     * @param options Request options.
     */
    getType<T = Issue.Type.GetType.Response.OK>(options: Issue.Type.GetType.Options): Promise<import("./definitions/issue_type").IssueType>;
    /**
     * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-createIssueType
     * @param options Request options.
     */
    createType<T = Issue.Type.CreateType.Response.OK>(options: Issue.Type.CreateType.Options): Promise<import("./definitions/issue_type").IssueType>;
    /**
     * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
     * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-deleteIssueType
     * @param options Request options.
     */
    deleteType<T = Issue.Type.DeleteType.Response.OK>(options: Issue.Type.DeleteType.Options): Promise<undefined>;
    /**
     * Updates the specified issue type from a JSON representation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-updateIssueType
     * @param options Request options.
     */
    updateType<T = Issue.Type.UpdateType.Response.OK>(options: Issue.Type.UpdateType.Options): Promise<import("./definitions/issue_type").IssueType>;
    /**
     * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
     * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getAlternativeIssueTypes
     * @param options Request options.
     */
    getAlternativeTypes<T = Issue.Type.GetAlternativeTypes.Response.OK>(options: Issue.Type.GetAlternativeTypes.Options): Promise<Issue.Type.GetAlternativeTypes.Response.OK>;
}
declare class MyselfGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns currently logged in user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/myself-getUser
     * @param options Request options.
     */
    getCurrentUser<T = Myself.GetCurrentUser.Response.OK>(options?: Myself.GetCurrentUser.Options): Promise<import("./definitions/user").UserFull>;
}
declare class PriorityGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all issue priorities.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/priority-getPriorities
     * @param options Request options.
     */
    getPriorities<T = Issue.Priority.GetPriorities.Response.OK>(options?: Issue.Priority.GetPriorities.Options): Promise<Issue.Priority.GetPriorities.Response.OK>;
    /**
     * Returns an issue priority.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/priority-getPriority
     * @param options Request options.
     */
    getPriority<T = Issue.Priority.GetPriority.Response.OK>(options: Issue.Priority.GetPriority.Options): Promise<import("./definitions/priority").Priority>;
}
declare class ProjectRoleGroup extends BaseGroup {
    Actor: RoleActorGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all roles in the given project Id or key, with links to full details on each role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRoles
     * @param options Request options.
     */
    getRoles<T = Project.Role.GetRoles.Response.OK>(options: Project.Role.GetRoles.Options): Promise<Record<string, string>>;
    /**
     * Returns the details for a given project role in a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRole
     * @param options Request options.
     */
    getRole<T = Project.Role.GetRole.Response.OK>(options: Project.Role.GetRole.Options): Promise<import("./definitions/project_role").ProjectRole>;
}
declare class RoleActorGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Updates a project role to include the specified actors (users or groups).
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-setActors
     * @param options Request options.
     */
    setActors<T = Project.Role.Actor.SetActors.Response.OK>(options: Project.Role.Actor.SetActors.Options): Promise<import("./definitions/project_role").ProjectRole>;
    /**
     * Adds an actor (user or group) to a project role.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-addActorUsers
     * @param options Request options.
     */
    addUsers<T = Project.Role.Actor.AddUsers.Response.OK>(options: Project.Role.Actor.AddUsers.Options): Promise<import("./definitions/project_role").ProjectRole>;
    /**
     * Deletes actors (users or groups) from a project role.
     * Delete a user from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?user={username}
     * Delete a group from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?group={groupname}
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-deleteActor
     * @param options Request options.
     */
    deleteActor<T = Project.Role.Actor.DeleteActor.Response.OK>(options: Project.Role.Actor.DeleteActor.Options): Promise<undefined>;
}
declare class ProjectTypeGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAllProjectTypes
     * @param options Request options.
     */
    getTypes<T = Project.Type.GetTypes.Response.OK>(options?: Project.Type.GetTypes.Options): Promise<Project.Type.GetTypes.Response.OK>;
    /**
     * Returns the project type with the given key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getProjectTypeByKey
     * @param options Request options.
     */
    getType<T = Project.Type.GetType.Response.OK>(options: Project.Type.GetType.Options): Promise<import("./definitions/project_type").ProjectType>;
    /**
     * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAccessibleProjectTypeByKey
     * @param options Request options.
     */
    getAccessibleType<T = Project.Type.GetAccessibleType.Response.OK>(options: Project.Type.GetAccessibleType.Options): Promise<import("./definitions/project_type").ProjectType>;
}
declare class ProjectValidationGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Validates a project key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/projectvalidate-getProject
     * @param options Request options.
     */
    validateProjectKey<T = Project.Validation.ValidateProjectKey.Response.OK>(options: Project.Validation.ValidateProjectKey.Options): Promise<Project.Validation.ValidateProjectKey.Response.OK>;
}
declare class ResolutionGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all resolutions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/resolution-getResolutions
     * @param options Request options.
     */
    getResolutions<T = Issue.Resolution.GetResolutions.Response.OK>(options?: Issue.Resolution.GetResolutions.Options): Promise<Issue.Resolution.GetResolutions.Response.OK>;
    /**
     * Returns a resolution.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/resolution-getResolution
     * @param options Request options.
     */
    getResolution<T = Issue.Resolution.GetResolution.Response.OK>(options: Issue.Resolution.GetResolution.Options): Promise<import("./definitions/resolution").Resolution>;
}
declare class SearchGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Performs a search using JQL.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/search-searchUsingSearchRequest
     * @param options Request options.
     */
    searchByJql<T = Issue.Search.SearchByJql.Response.OK>(options: Issue.Search.SearchByJql.Options): Promise<Issue.Search.SearchByJql.Response.OK>;
}
declare class WorkflowGroup extends BaseGroup {
    Status: WorkflowStatusGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all workflows.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/workflow-getAllWorkflows
     * @param options Request options.
     */
    getWorkflows<T = Workflow.GetWorkflows.Response.OK>(options?: Workflow.GetWorkflows.Options): Promise<Workflow.GetWorkflows.Response.OK>;
}
declare class WorkflowStatusGroup extends BaseGroup {
    Category: StatusCategoryGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all statuses.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatuses
     * @param options Request options.
     */
    getStatuses<T = Workflow.Status.GetStatuses.Response.OK>(options?: Workflow.Status.GetStatuses.Options): Promise<Workflow.Status.GetStatuses.Response.OK>;
    /**
     * Returns a full representation of the Status having the given id or name.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatus
     * @param options Request options.
     */
    getStatus<T = Workflow.Status.GetStatus.Response.OK>(options: Workflow.Status.GetStatus.Options): Promise<import("./definitions/status").Status>;
}
declare class StatusCategoryGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all status categories.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategories
     * @param options Request options.
     */
    getCategories<T = Workflow.Status.Category.GetCategories.Response.OK>(options?: Workflow.Status.Category.GetCategories.Options): Promise<Workflow.Status.Category.GetCategories.Response.OK>;
    /**
     * Returns a full representation of the StatusCategory having the given id or key.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategory
     * @param options Request options.
     */
    getCategory<T = Workflow.Status.Category.GetCategory.Response.OK>(options: Workflow.Status.Category.GetCategory.Options): Promise<import("./definitions/status_category").StatusCategory>;
}
declare class UserGroup extends BaseGroup {
    Search: UserSearchGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-getUser
     * @param options Request options.
     */
    getUser<T = User.GetUser.Response.OK>(options: User.GetUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-updateUser
     * @param options Request options.
     */
    updateUser<T = User.UpdateUser.Response.OK>(options: User.UpdateUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-createUser
     * @param options Request options.
     */
    createUser<T = User.CreateUser.Response.OK>(options: User.CreateUser.Options): Promise<import("./definitions/user").UserFull>;
    /**
     * Removes user and its references (like project roles associations, watches, history).
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUser
     * @param options Request options.
     */
    removeUser<T = User.RemoveUser.Response.OK>(options: User.RemoveUser.Options): Promise<undefined>;
    /**
     * Add user to given application. Admin permission will be required to perform this operation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-addUserToApplication
     * @param options Request options.
     */
    addUserToApplication<T = User.AddUserToApplication.Response.OK>(options: User.AddUserToApplication.Options): Promise<undefined>;
    /**
     * Remove user from given application. Admin permission will be required to perform this operation.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUserFromApplication
     * @param options Request options.
     */
    removeUserFromApplication<T = User.RemoveUserFromApplication.Response.OK>(options: User.RemoveUserFromApplication.Options): Promise<undefined>;
    /**
     * Modify user password.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-changeUserPassword
     * @param options Request options.
     */
    changeUserPassword<T = User.ChangeUserPassword.Response.OK>(options: User.ChangeUserPassword.Options): Promise<undefined>;
}
declare class UserSearchGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously. Please note that this resource should be called with an issue key when a list of assignable users is retrieved for editing. For create only a project key should be supplied. The list of assignable users may be incorrect if it's called with the project key for editing.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findAssignableUsers
     * @param options Request options.
     */
    findAssignableUsers<T = User.Search.FindAssignableUsers.Response.OK>(options: User.Search.FindAssignableUsers.Options): Promise<User.Search.FindAssignableUsers.Response.OK>;
    /**
     * Returns a list of active users that match the search string and have all specified permissions for the project or issue.
     * This resource can be accessed by users with ADMINISTER_PROJECT permission for the project or global ADMIN or SYSADMIN rights.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithAllPermissions
     * @param options Request options.
     */
    findUsersWithAllPermissions<T = User.Search.FindUsersWithAllPermissions.Response.OK>(options: User.Search.FindUsersWithAllPermissions.Options): Promise<User.Search.FindUsersWithAllPermissions.Response.OK>;
    /**
     * Returns a list of users that match the search string. This resource cannot be accessed anonymously.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsers
     * @param options Request options.
     */
    findUsers<T = User.Search.FindUsers.Response.OK>(options: User.Search.FindUsers.Options): Promise<User.Search.FindUsers.Response.OK>;
    /**
     * Returns a list of active users that match the search string. This resource cannot be accessed anonymously and requires the Browse Users global permission. Given an issue key this resource will provide a list of users that match the search string and have the browse issue permission for the issue provided.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithBrowsePermission
     * @param options Request options.
     */
    findUsersWithBrowsePermission<T = User.Search.FindUsersWithBrowsePermission.Response.OK>(options: User.Search.FindUsersWithBrowsePermission.Options): Promise<User.Search.FindUsersWithBrowsePermission.Response.OK>;
}
declare class ProjectVersionGroup extends BaseGroup {
    Count: VersionCountGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Create a version via POST.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-createVersion
     * @param options Request options.
     */
    createVersion<T = Project.Version.CreateVersion.Response.OK>(options: Project.Version.CreateVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Modify a version's sequence within a project.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-moveVersion
     * @param options Request options.
     */
    moveVersion<T = Project.Version.MoveVersion.Response.OK>(options: Project.Version.MoveVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Returns a project version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersion
     * @param options Request options.
     */
    getVersion<T = Project.Version.GetVersion.Response.OK>(options: Project.Version.GetVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Modify a version via PUT. Any fields present in the PUT will override existing values. As a convenience, if a field is not present, it is silently ignored.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-updateVersion
     * @param options Request options.
     */
    updateVersion<T = Project.Version.UpdateVersion.Response.OK>(options: Project.Version.UpdateVersion.Options): Promise<import("./definitions/version").Version>;
    /**
     * Delete a project version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
     * @param options Request options.
     */
    deleteVersion<T = Project.Version.DeleteVersion.Response.OK>(options: Project.Version.DeleteVersion.Options): Promise<undefined>;
    /**
     * Merge versions.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-merge
     * @param options Request options.
     */
    mergeVersion<T = Project.Version.MergeVersion.Response.OK>(options: Project.Version.MergeVersion.Options): Promise<undefined>;
    /**
     * Delete a project version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
     * @param options Request options.
     */
    removeAndReplaceVersion<T = Project.Version.RemoveAndReplaceVersion.Response.OK>(options: Project.Version.RemoveAndReplaceVersion.Options): Promise<undefined>;
}
declare class VersionCountGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a bean containing the number of fixed in and affected issues for the given version.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionRelatedIssues
     * @param options Request options.
     */
    getVersionRelatedIssueCount<T = Project.Version.Count.GetVersionRelatedIssueCount.Response.OK>(options: Project.Version.Count.GetVersionRelatedIssueCount.Options): Promise<Project.Version.Count.GetVersionRelatedIssueCount.Response.OK>;
    /**
     * Returns the number of unresolved issues for the given version
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionUnresolvedIssues
     * @param options Request options.
     */
    getVersionUnresolvedIssueCount<T = Project.Version.Count.GetVersionUnresolvedIssueCount.Response.OK>(options: Project.Version.Count.GetVersionUnresolvedIssueCount.Options): Promise<Project.Version.Count.GetVersionUnresolvedIssueCount.Response.OK>;
}
declare class RoleGroup extends BaseGroup {
    Project: RoleProjectGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class RoleProjectGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Get all the ProjectRoles available in JIRA. Currently this list is global.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/role-getProjectRoles
     * @param options Request options.
     */
    getRoles<T = Role.Project.GetRoles.Response.OK>(options?: Role.Project.GetRoles.Options): Promise<Role.Project.GetRoles.Response.OK>;
    /**
     * Get a specific ProjectRole available in JIRA.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/role-getProjectRolesById
     * @param options Request options.
     */
    getRole<T = Role.Project.GetRole.Response.OK>(options: Role.Project.GetRole.Options): Promise<import("./definitions/project_role").ProjectRole>;
}
declare class PermissionGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all permissions that are present in the JIRA instance - Global, Project and the global ones added by plugins
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getAllPermissions
     * @param options Request options.
     */
    getPermissions<T = Permission.GetPermissions.Response.OK>(options?: Permission.GetPermissions.Options): Promise<import("./definitions/permissions").Permissions>;
    /**
     * Returns all permissions in the system and whether the currently logged in user has them.
     * You can optionally provide a specific context to get permissions for (projectKey OR projectId OR issueKey OR issueId).
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getPermissions
     * @param options Request options.
     */
    getMyPermissions<T = Permission.GetMyPermissions.Response.OK>(options?: Permission.GetMyPermissions.Options): Promise<import("./definitions/permissions").Permissions>;
}
declare class DashboardGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a list of all dashboards, optionally filtering them.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-list
     * @param options Request options.
     */
    getDashboards<T = Dashboard.GetDashboards.Response.OK>(options?: Dashboard.GetDashboards.Options): Promise<import("./definitions/dashboard").Dashboards>;
    /**
     * Returns a single dashboard.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-getDashboard
     * @param options Request options.
     */
    getDashboard<T = Dashboard.GetDashboard.Response.OK>(options: Dashboard.GetDashboard.Options): Promise<import("./definitions/dashboard").Dashboard>;
}
declare class SharePermissionGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns all share permissions of the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermissions
     * @param options Request options.
     */
    getSharePermissions<T = Filter.Share.Permission.GetSharePermissions.Response.OK>(options: Filter.Share.Permission.GetSharePermissions.Options): Promise<Filter.Share.Permission.GetSharePermissions.Response.OK>;
    /**
     * Adds a share permissions to the given filter. Adding a global permission removes all previous permissions from the filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-addSharePermission
     * @param options Request options.
     */
    addSharePermission<T = Filter.Share.Permission.AddSharePermissions.Response.OK>(options: Filter.Share.Permission.AddSharePermissions.Options): Promise<Filter.Share.Permission.AddSharePermissions.Response.OK>;
    /**
     * Returns a single share permission of the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
     * @param options Request options.
     */
    getSharePermission<T = Filter.Share.Permission.GetSharePermission.Response.OK>(options: Filter.Share.Permission.GetSharePermission.Options): Promise<import("./definitions/filter").FilterPermission>;
    /**
     * Removes a share permissions from the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
     * @param options Request options.
     */
    deleteSharePermission<T = Filter.Share.Permission.DeleteSharePermission.Response.OK>(options: Filter.Share.Permission.DeleteSharePermission.Options): Promise<undefined>;
}
declare class SchemeGroup extends BaseGroup {
    Notification: SchemeNotificationGroup;
    constructor(connection: string, options: ConnectionOptions);
}
declare class SchemeNotificationGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns a paginated list of notification schemes.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/notificationscheme-getNotificationSchemes
     * @param options Request options.
     */
    getSchemes<T = Scheme.Notification.GetSchemes.Response.OK>(options?: Scheme.Notification.GetSchemes.Options): Promise<Scheme.Notification.GetSchemes.Response.OK>;
}
declare class FilterColumnGroup extends BaseGroup {
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns the default columns for the given filter. Currently logged in user will be used as the user making such request.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-defaultColumns
     * @param options Request options.
     */
    getDefaultColumns<T = Filter.Column.GetDefaultColumns.Response.OK>(options: Filter.Column.GetDefaultColumns.Options): Promise<Filter.Column.GetDefaultColumns.Response.OK>;
    /**
     * Sets the default columns for the given filter.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setColumns
     * @param options Request options.
     */
    setDefaultColumns<T = Filter.Column.SetDefaultColumns.Response.OK>(options: Filter.Column.SetDefaultColumns.Options): Promise<undefined>;
    /**
     * Resets the columns for the given filter such that the filter no longer has its own column config.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-resetColumns
     * @param options Request options.
     */
    resetColumns<T = Filter.Column.ResetColumns.Response.OK>(options: Filter.Column.ResetColumns.Options): Promise<undefined>;
}
declare class FilterShareGroup extends BaseGroup {
    Permission: SharePermissionGroup;
    constructor(connection: string, options: ConnectionOptions);
    /**
     * Returns the default share scope of the logged-in user.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getDefaultShareScope
     * @param options Request options.
     */
    getShareScope<T = Filter.Share.GetDefaultScope.Response.OK>(options?: Filter.Share.GetDefaultScope.Options): Promise<Filter.Share.GetDefaultScope.Response.OK>;
    /**
     * Sets the default share scope of the logged-in user. Available values are GLOBAL and PRIVATE.
     * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setDefaultShareScope
     * @param options Request options.
     */
    setShareScope<T = Filter.Share.SetDefaultScope.Response.OK>(options: Filter.Share.SetDefaultScope.Options): Promise<Filter.Share.SetDefaultScope.Response.OK>;
}
export {};
//# sourceMappingURL=index.d.ts.map