import { httpGet, httpPut } from './common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns the information if the optional features in JIRA are enabled or disabled. If the time tracking is enabled, it also returns the detailed information about time tracking configuration.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/configuration-getConfiguration
 * @param options Request options.
 */
export function getInstanceConfiguration(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/configuration', headers);
}
/**
 * Returns an application property.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getProperty
 * @param options Request options.
 */
export function getApplicationProperty(options) {
    const { connectionId: instanceId, headers, key, keyFilter, permissionLevel } = options;
    const queryParams = { key, keyFilter, permissionLevel };
    return httpGet(instanceId, constructUrl('/rest/api/2/application-properties', queryParams), headers);
}
/**
 * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-setPropertyViaRestfulTable
 * @param options Request options.
 */
export function setApplicationProperty(options) {
    const { connectionId: instanceId, id, body, headers } = options;
    return httpPut(instanceId, `/rest/api/2/application-properties/${id}`, body, headers);
}
/**
 * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getAdvancedSettings
 * @param options Request options.
 */
export function getAdvancedSettings(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/application-properties/advanced-settings', headers);
}
/**
 * Returns general information about the current JIRA server.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/serverInfo-getServerInfo
 * @param options Request options.
 */
export function getInstanceInfo(options) {
    const { connectionId: instanceId, headers, doHealthCheck } = options;
    const queryParams = { doHealthCheck };
    return httpGet(instanceId, constructUrl('/rest/api/2/serverInfo', queryParams), headers);
}
