import { httpPost, httpGet, httpDelete, httpPut } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns all comments for an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComments
 * @param options Request options.
 */
export function getIssueComments(options) {
    const { connectionId: instanceId, issueIdOrKey, headers, expand, startAt, maxResults, orderBy } = options;
    const queryParams = { expand, startAt, maxResults, orderBy };
    return httpGet(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/comment`, queryParams), headers);
}
/**
 * Adds a new comment to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addComment
 * @param options Request options.
 */
export function addIssueComment(options) {
    const { connectionId: instanceId, issueIdOrKey, body, headers, expand } = options;
    const queryParams = { expand };
    return httpPost(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/comment`, queryParams), body, headers);
}
/**
 * Returns a single comment.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComment
 * @param options Request options.
 */
export function getIssueComment(options) {
    const { connectionId: instanceId, issueIdOrKey, id, headers, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/comment/${id}`, queryParams), headers);
}
/**
 * Updates an existing comment using its JSON representation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateComment
 * @param options Request options.
 */
export function updateIssueComment(options) {
    const { connectionId: instanceId, issueIdOrKey, id, body, headers, expand } = options;
    const queryParams = { expand };
    return httpPut(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/comment/${id}`, queryParams), body, headers);
}
/**
 * Deletes an existing comment.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteComment
 * @param options Request options.
 */
export function deleteIssueComment(options) {
    const { connectionId: instanceId, issueIdOrKey, id, headers } = options;
    return httpDelete(instanceId, `/rest/api/2/issue/${issueIdOrKey}/comment/${id}`, headers, true);
}
