import { httpPost, httpGet, httpDelete, httpPut } from '../../common';
import { constructUrl } from '@avst-api/commons';
/**
 * A REST sub-resource representing the remote issue links on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinks
 * @param options Request options.
 */
export function getRemoteIssueLinks(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/remotelink`, headers);
}
/**
 * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createOrUpdateRemoteIssueLink
 * @param options Request options.
 */
export function createOrUpdateRemoteIssueLink(options) {
    const { connectionId: instanceId, issueIdOrKey, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/issue/${issueIdOrKey}/remotelink`, body, headers);
}
/**
 * Delete the remote issue link with the given global id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkByGlobalId
 * @param options Request options.
 */
export function deleteRemoteIssueLinkByGlobalId(options) {
    const { connectionId: instanceId, issueIdOrKey, headers, globalId } = options;
    const queryParams = { globalId };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/remotelink`, queryParams), headers, true);
}
/**
 * Get the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinkById
 * @param options Request options.
 */
export function getRemoteIssueLink(options) {
    const { connectionId: instanceId, issueIdOrKey, linkId, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/remotelink/${linkId}`, headers);
}
/**
 * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateRemoteIssueLink
 * @param options Request options.
 */
export function updateRemoteIssueLink(options) {
    const { connectionId: instanceId, issueIdOrKey, linkId, body, headers } = options;
    return httpPut(instanceId, `/rest/api/2/issue/${issueIdOrKey}/remotelink/${linkId}`, body, headers, true);
}
/**
 * Delete the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkById
 * @param options Request options.
 */
export function deleteRemoteIssueLink(options) {
    const { connectionId: instanceId, issueIdOrKey, linkId, headers } = options;
    return httpDelete(instanceId, `/rest/api/2/issue/${issueIdOrKey}/remotelink/${linkId}`, headers, true);
}
