import { httpDelete, httpGet, httpPost, httpPut } from '../../common';
/**
 * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkTypes
 * @param options Request options.
 */
export function getIssueLinkTypes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/issueLinkType', headers);
}
/**
 * Returns for a given issue link type id all information about this issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkType
 * @param options Request options.
 */
export function getIssueLinkType(options) {
    const { connectionId: instanceId, issueLinkTypeId, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issueLinkType/${issueLinkTypeId}`, headers);
}
/**
 * Create a new issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-createIssueLinkType
 * @param options Request options.
 */
export function createIssueLinkType(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, '/rest/api/2/issueLinkType/', body, headers);
}
/**
 * Delete the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-deleteIssueLinkType
 * @param options Request options.
 */
export function deleteIssueLinkType(options) {
    const { connectionId: instanceId, issueLinkTypeId, headers } = options;
    return httpDelete(instanceId, `/rest/api/2/issueLinkType/${issueLinkTypeId}`, headers, true);
}
/**
 * Update the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-updateIssueLinkType
 * @param options Request options.
 */
export function updateIssueLinkType(options) {
    const { connectionId: instanceId, issueLinkTypeId, headers, body } = options;
    return httpPut(instanceId, `/rest/api/2/issueLinkType/${issueLinkTypeId}`, body, headers);
}
