import { constructUrl } from '@avst-api/commons';
import { httpDelete, httpGet, httpPost, httpPut } from '../common';
/**
 * Returns a list of all issue types visible to the user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueAllTypes
 * @param options Request options.
 */
export function getIssueTypes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/issuetype', headers);
}
/**
 * Returns a full representation of the issue type that has the given id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueType
 * @param options Request options.
 */
export function getIssueType(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issuetype/${id}`, headers);
}
/**
 * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-createIssueType
 * @param options Request options.
 */
export function createIssueType(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPost(instanceId, '/rest/api/2/issuetype', body, headers);
}
/**
 * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
 * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-deleteIssueType
 * @param options Request options.
 */
export function deleteIssueType(options) {
    const { connectionId: instanceId, headers, id, alternativeIssueTypeId } = options;
    const queryParams = { alternativeIssueTypeId };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/issuetype/${id}`, queryParams), headers, true);
}
/**
 * Updates the specified issue type from a JSON representation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-updateIssueType
 * @param options Request options.
 */
export function updateIssueType(options) {
    const { connectionId: instanceId, headers, body, id } = options;
    return httpPut(instanceId, `/rest/api/2/issuetype/${id}`, body, headers);
}
/**
 * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
 * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getAlternativeIssueTypes
 * @param options Request options.
 */
export function getAlternativeIssueTypes(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/2/issuetype/${id}/alternatives`, headers);
}
