import { httpPost, httpGet, httpDelete, httpPut } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWorklog
 * @param options Request options.
 */
export function getIssueWorklogs(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/worklog`, headers);
}
/**
 * Adds a new worklog entry to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWorklog
 * @param options Request options.
 */
export function addIssueWorklog(options) {
    const { connectionId: instanceId, issueIdOrKey, body, headers, adjustEstimate, newEstimate, reduceBy } = options;
    const queryParams = { adjustEstimate, newEstimate, reduceBy };
    return httpPost(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/worklog`, queryParams), body, headers);
}
/**
 * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getWorklog
 * @param options Request options.
 */
export function getIssueWorklog(options) {
    const { connectionId: instanceId, issueIdOrKey, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/worklog/${id}`, headers);
}
/**
 * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateWorklog
 * @param options Request options.
 */
export function updateIssueWorklog(options) {
    const { connectionId: instanceId, issueIdOrKey, id, body, headers, newEstimate, adjustEstimate } = options;
    const queryParams = { adjustEstimate, newEstimate };
    return httpPut(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/worklog/${id}`, queryParams), body, headers);
}
/**
 * Deletes an existing worklog entry.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteWorklog
 * @param options Request options.
 */
export function deleteIssueWorklog(options) {
    const { connectionId: instanceId, issueIdOrKey, id, headers, adjustEstimate, newEstimate, increaseBy } = options;
    const queryParams = { adjustEstimate, newEstimate, increaseBy };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/worklog/${id}`, queryParams), headers, true);
}
/**
 * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsDeletedSince
 * @param options Request options.
 */
export function getDeletedIssueWorklogIds(options) {
    const { connectionId: instanceId, headers, since } = options;
    const queryParams = { since };
    return httpGet(instanceId, constructUrl('/rest/api/2/worklog/deleted', queryParams), headers);
}
/**
 * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getWorklogsForIds
 * @param options Request options.
 */
export function getIssueWorklogsForIds(options) {
    const { connectionId: instanceId, body, headers } = options;
    return httpPost(instanceId, '/rest/api/2/worklog/list', body, headers);
}
/**
 * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsModifiedSince
 * @param options Request options.
 */
export function getUpdatedIssueWorklogIds(options) {
    const { connectionId: instanceId, headers, since } = options;
    const queryParams = { since };
    return httpGet(instanceId, constructUrl('/rest/api/2/worklog/updated', queryParams), headers);
}
