import { httpGet, httpPost, httpPut, httpDelete } from './common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllProjects
 * @param options Request options.
 */
export function getProjects(options) {
    const { connectionId: instanceId, headers, expand, includeArchived, recent } = options;
    const queryParams = { expand, includeArchived, recent };
    return httpGet(instanceId, constructUrl('/rest/api/2/project', queryParams), headers);
}
/**
 * Creates a new project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-createProject
 * @param options Request options.
 */
export function createProject(options) {
    const { connectionId: instanceId, body, headers } = options;
    return httpPost(instanceId, '/rest/api/2/project', body, headers);
}
/**
 * Contains a full representation of a project in JSON format.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProject
 * @param options Request options.
 */
export function getProject(options) {
    const { connectionId: instanceId, projectIdOrKey, headers, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/2/project/${projectIdOrKey}`, queryParams), headers);
}
/**
 * Updates a project. Only non null values sent in JSON will be updated in the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProject
 * @param options Request options.
 */
export function updateProject(options) {
    const { connectionId: instanceId, projectIdOrKey, body, headers, expand } = options;
    const queryParams = { expand };
    return httpPut(instanceId, constructUrl(`/rest/api/2/project/${projectIdOrKey}`, queryParams), body, headers);
}
/**
 * Deletes a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-deleteProject
 * @param options Request options.
 */
export function deleteProject(options) {
    const { connectionId: instanceId, projectIdOrKey, headers } = options;
    return httpDelete(instanceId, `/rest/api/2/project/${projectIdOrKey}`, headers, true);
}
/**
 * Archives a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-archiveProject
 * @param options Request options.
 */
export function archiveProject(options) {
    const { connectionId: instanceId, projectIdOrKey, headers } = options;
    return httpPut(instanceId, `/rest/api/2/project/${projectIdOrKey}/archive`, undefined, headers, true);
}
/**
 * Contains a full representation of a the specified project's components.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectComponents
 * @param options Request options.
 */
export function getProjectComponents(options) {
    const { connectionId: instanceId, projectIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/project/${projectIdOrKey}/components`, headers);
}
/**
 * Restore an archived project. In case of success restored project should be re-indexed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-restoreProject
 * @param options Request options.
 */
export function restoreProject(options) {
    const { connectionId: instanceId, projectIdOrKey, headers } = options;
    return httpPut(instanceId, `/rest/api/2/project/${projectIdOrKey}/restore`, undefined, headers, true);
}
/**
 * Get all issue types with valid status values for a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllStatuses
 * @param options Request options.
 */
export function getProjectStatuses(options) {
    const { connectionId: instanceId, projectIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/project/${projectIdOrKey}/statuses`, headers);
}
/**
 * Updates the type of a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProjectType
 * @param options Request options.
 */
export function updateProjectType(options) {
    const { connectionId: instanceId, projectIdOrKey, newProjectTypeKey, headers } = options;
    return httpPut(instanceId, `/rest/api/2/project/${projectIdOrKey}/type/${newProjectTypeKey}`, undefined, headers);
}
/**
 * Returns all versions for the specified project. Results are paginated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersionsPaginated
 * @param options Request options.
 */
export function getProjectVersionsPaginated(options) {
    const { connectionId: instanceId, projectIdOrKey, headers, expand, maxResults, orderBy, startAt } = options;
    const queryParams = { expand, maxResults, orderBy, startAt };
    return httpGet(instanceId, constructUrl(`/rest/api/2/project/${projectIdOrKey}/version`, queryParams), headers);
}
/**
 * Contains a full representation of a the specified project's versions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersions
 * @param options Request options.
 */
export function getProjectVersions(options) {
    const { connectionId: instanceId, projectIdOrKey, headers, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/2/project/${projectIdOrKey}/versions`, queryParams), headers);
}
