import { httpGet, httpPost, httpPut, httpDelete } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Create a version via POST.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-createVersion
 * @param options Request options.
 */
export function createProjectVersion(options) {
    const { connectionId: instanceId, body, headers } = options;
    return httpPost(instanceId, '/rest/api/2/version', body, headers);
}
/**
 * Modify a version's sequence within a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-moveVersion
 * @param options Request options.
 */
export function moveProjectVersion(options) {
    const { connectionId: instanceId, id, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/version/${id}/move`, body, headers);
}
/**
 * Returns a project version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersion
 * @param options Request options.
 */
export function getProjectVersion(options) {
    const { connectionId: instanceId, id, headers, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/2/version/${id}`, queryParams), headers);
}
/**
 * Modify a version via PUT. Any fields present in the PUT will override existing values. As a convenience, if a field is not present, it is silently ignored.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-updateVersion
 * @param options Request options.
 */
export function updateProjectVersion(options) {
    const { connectionId: instanceId, id, body, headers } = options;
    return httpPut(instanceId, `/rest/api/2/version/${id}`, body, headers);
}
/**
 * Delete a project version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
 * @param options Request options.
 */
export function deleteProjectVersion(options) {
    const { connectionId: instanceId, id, headers, moveAffectedIssuesTo, moveFixIssuesTo } = options;
    const queryParams = { moveAffectedIssuesTo, moveFixIssuesTo };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/version/${id}`, queryParams), headers, true);
}
/**
 * Merge versions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-merge
 * @param options Request options.
 */
export function mergeProjectVersion(options) {
    const { connectionId: instanceId, id, moveIssuesTo, headers } = options;
    return httpPut(instanceId, `/rest/api/2/version/${id}/mergeto/${moveIssuesTo}`, undefined, headers, true);
}
/**
 * Delete a project version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
 * @param options Request options.
 */
export function removeAndReplaceProjectVersion(options) {
    const { connectionId: instanceId, id, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/version/${id}/removeAndSwap`, body, headers, true);
}
