import { httpGet, httpDelete, httpPost, httpPut } from './common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns a user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-getUser
 * @param options Request options.
 */
export function getUser(options) {
    const { connectionId: instanceId, headers, key, username } = options;
    const queryParams = { key, username };
    return httpGet(instanceId, constructUrl('/rest/api/2/user', queryParams), headers);
}
/**
 * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-updateUser
 * @param options Request options.
 */
export function updateUser(options) {
    const { connectionId: instanceId, body, headers, key, username } = options;
    const queryParams = { key, username };
    return httpPut(instanceId, constructUrl('/rest/api/2/user', queryParams), body, headers);
}
/**
 * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-createUser
 * @param options Request options.
 */
export function createUser(options) {
    const { connectionId: instanceId, body, headers } = options;
    return httpPost(instanceId, '/rest/api/2/user', body, headers);
}
/**
 * Removes user and its references (like project roles associations, watches, history).
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUser
 * @param options Request options.
 */
export function removeUser(options) {
    const { connectionId: instanceId, headers, key, username } = options;
    const queryParams = { key, username };
    return httpDelete(instanceId, constructUrl('/rest/api/2/user', queryParams), headers, true);
}
/**
 * Add user to given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-addUserToApplication
 * @param options Request options.
 */
export function addUserToApplication(options) {
    const { connectionId: instanceId, headers, applicationKey, username } = options;
    const queryParams = { applicationKey, username };
    return httpPost(instanceId, constructUrl('/rest/api/2/user/application', queryParams), undefined, headers, true);
}
/**
 * Remove user from given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUserFromApplication
 * @param options Request options.
 */
export function removeUserFromApplication(options) {
    const { connectionId: instanceId, headers, applicationKey, username } = options;
    const queryParams = { applicationKey, username };
    return httpDelete(instanceId, constructUrl('/rest/api/2/user/application', queryParams), headers, true);
}
/**
 * Modify user password.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-changeUserPassword
 * @param options Request options.
 */
export function changeUserPassword(options) {
    const { connectionId: instanceId, body, headers, key, username } = options;
    const queryParams = { key, username };
    return httpPut(instanceId, constructUrl('/rest/api/2/user/password', queryParams), body, headers, true);
}
