import { httpGet } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns a list of users that match the search string. This resource cannot be accessed anonymously. Please note that this resource should be called with an issue key when a list of assignable users is retrieved for editing. For create only a project key should be supplied. The list of assignable users may be incorrect if it's called with the project key for editing.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findAssignableUsers
 * @param options Request options.
 */
export function findAssignableUsers(options) {
    const { connectionId: instanceId, headers, username, startAt, maxResults, actionDescriptorId, issueKey, project } = options;
    const queryParams = { username, startAt, maxResults, actionDescriptorId, issueKey, project };
    return httpGet(instanceId, constructUrl('/rest/api/2/user/assignable/search', queryParams), headers);
}
/**
 * Returns a list of active users that match the search string and have all specified permissions for the project or issue.
 * This resource can be accessed by users with ADMINISTER_PROJECT permission for the project or global ADMIN or SYSADMIN rights.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithAllPermissions
 * @param options Request options.
 */
export function findUsersWithAllPermissions(options) {
    const { connectionId: instanceId, headers, username, startAt, maxResults, issueKey, permissions, projectKey } = options;
    const queryParams = { username, startAt, maxResults, issueKey, permissions, projectKey };
    return httpGet(instanceId, constructUrl('/rest/api/2/user/permission/search', queryParams), headers);
}
/**
 * Returns a list of users that match the search string. This resource cannot be accessed anonymously.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsers
 * @param options Request options.
 */
export function findUsers(options) {
    const { connectionId: instanceId, headers, username, startAt, maxResults, includeActive, includeInactive } = options;
    const queryParams = { username, startAt, maxResults, includeActive, includeInactive };
    return httpGet(instanceId, constructUrl('/rest/api/2/user/search', queryParams), headers);
}
/**
 * Returns a list of active users that match the search string. This resource cannot be accessed anonymously and requires the Browse Users global permission. Given an issue key this resource will provide a list of users that match the search string and have the browse issue permission for the issue provided.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithBrowsePermission
 * @param options Request options.
 */
export function findUsersWithBrowsePermission(options) {
    const { connectionId: instanceId, headers, username, startAt, maxResults, projectKey, issueKey } = options;
    const queryParams = { username, startAt, maxResults, projectKey, issueKey };
    return httpGet(instanceId, constructUrl('/rest/api/2/user/viewissue/search', queryParams), headers);
}
